@@ -2,22 +2,13 @@
 #include <iostream>
 #include <stdlib.h>
 #include <swmgr.h>
+#include <swmodule.h>
 
-#ifndef NO_SWORD_NAMESPACE
-using sword::SWMgr;
-using sword::SWModule;
-using sword::ModMap;
-using sword::SWKey;
-using sword::AttributeTypeList;
-using sword::AttributeValue;
-using sword::AttributeList;
-#endif
 
 int main(int argc, char **argv)
 {
-	SWMgr manager(0, 0, true, 0, true);
-	SWModule *target;
-	ModMap::iterator it;
+	sword::SWMgr manager(0, 0, true, 0, true);
+	sword::SWModule *target;
 
 	if (argc != 3) {
 		fprintf(stderr, "\nusage: %s <modname> <\"lookup key\">\n"
@@ -26,9 +17,10 @@ int main(int argc, char **argv)
 		exit(-1);
 	}
 
-	it = manager.Modules.find(argv[1]);
-	if (it == manager.Modules.end()) {
+	target = manager.getModule(argv[1]);
+	if (!target) {
 		fprintf(stderr, "Could not find module [%s].  Available modules:\n", argv[1]);
+		sword::ModMap::iterator it;
 		for (it = manager.Modules.begin(); it != manager.Modules.end(); it++) {
 			fprintf(stderr, "[%s]\t - %s\n", (*it).second->Name(), (*it).second->Description());
 		}
@@ -36,22 +28,20 @@ int main(int argc, char **argv)
 	}
 
 	manager.setGlobalOption("Headings", "On");
-
-	target = (*it).second;
+//	manager.setGlobalOption("Greek Accents", "Off");
 
 	target->setKey(argv[2]);
 
-	(const char *)*target;		// force an entry lookup to resolve key so we
-						// get the idxbuf entry for the key
-	std::cout << (const char *)(SWKey &)*target << ":\n";
-//	std::cout << target->StripText();
+	target->RenderText();		// force an entry lookup to resolve key to something in the index
+
+	std::cout << target->getKeyText() << ":\n";
 	std::cout << target->getRawEntry();
 	std::cout << "\n";
 	std::cout << "==========================\n";
 	std::cout << "Entry Attributes:\n\n";
-	AttributeTypeList::iterator i1;
-	AttributeList::iterator i2;
-	AttributeValue::iterator i3;
+	sword::AttributeTypeList::iterator i1;
+	sword::AttributeList::iterator i2;
+	sword::AttributeValue::iterator i3;
 	for (i1 = target->getEntryAttributes().begin(); i1 != target->getEntryAttributes().end(); i1++) {
 		std::cout << "[ " << i1->first << " ]\n";
 		for (i2 = i1->second.begin(); i2 != i1->second.end(); i2++) {
