@@ -1,9 +1,9 @@
 /******************************************************************************
  * canon.h - Canonical text information to be included by VerseKey.cpp
  *
- * $Id: canon.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: canon.h 1864 2005-11-20 06:06:40Z scribe $
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 1998-2005 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -24,9 +24,6 @@
  *		and chapmax
  */
 
-#include <defs.h>
-//SWORD_NAMESPACE_START
-
 struct sbook
   VerseKey::otbooks[] = {
   {"Genesis", "Gen", 50},
@@ -698,4 +695,3 @@ int
 , {sizeof (VerseKey::ntbks) / sizeof(long), sizeof (VerseKey::ntcps) / sizeof(long)}
 };
 
-//SWORD_NAMESPACE_END
