@@ -1,7 +1,7 @@
 /******************************************************************************
 *  filemgr.h   - definition of class FileMgr used for pooling file handles
 *
-* $Id: filemgr.h 1807 2005-05-13 00:44:17Z chrislit $
+* $Id: filemgr.h 1864 2005-11-20 06:06:40Z scribe $
 *
 * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
 *	CrossWire Bible Society
@@ -26,11 +26,11 @@
 #include <fcntl.h>
 
 #include <defs.h>
-#include <swbuf.h>
 #include <swcacher.h>
 
 SWORD_NAMESPACE_START
 
+class SWBuf;
 
 class SWDLLEXPORT FileMgr;
 
