@@ -1,19 +1,36 @@
+/******************************************************************************
+ *	swordapi.h	- This file contains an api usable by non-C++
+ *					environments
+ *
+ * $Id: flatapi.h 1685 2004-12-22 07:05:49Z scribe $
+ *
+ * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
+
 #ifndef SWORDAPI_H
 #define SWORDAPI_H
 
-//#include <swmodule.h>
-//#include <swkey.h>
-//#include <versekey.h>
-//#include <swmgr.h>
 #include <defs.h>
 #ifdef __cplusplus
 #endif
 
 extern "C" {
 
-#define SWHANDLE int
+#define SWHANDLE long
 
-//using namespace sword;
 
 //-----------------------------------------------------------------
 // stringlist_iterator methods
@@ -21,7 +38,12 @@ extern "C" {
 void SWDLLEXPORT stringlist_iterator_next(SWHANDLE hsli);
 const char * SWDLLEXPORT stringlist_iterator_val(SWHANDLE hsli);
 
+//-----------------------------------------------------------------
+// listkey_iterator methods
 
+void SWDLLEXPORT listkey_iterator_next(SWHANDLE lki);
+const char * SWDLLEXPORT listkey_iterator_val(SWHANDLE hsli);
+	
 //-----------------------------------------------------------------
 // modmap methods
 //
@@ -32,7 +54,7 @@ SWHANDLE SWDLLEXPORT ModList_iterator_val(SWHANDLE hmmi);
 //-----------------------------------------------------------------
 // SWMgr methods
 //
-SWHANDLE SWDLLEXPORT SWMgr_new();
+SWHANDLE SWDLLEXPORT SWMgr_new(char filterType);
 // SWConfig *, SWConfig *, bool, SWFilterMgr *
 SWHANDLE SWDLLEXPORT SWMgr_newEx(SWHANDLE hiconfig, SWHANDLE hisysconfig, char autoload, SWHANDLE hfilterMgr);
 void     SWDLLEXPORT SWMgr_delete(SWHANDLE hmgr);
@@ -55,6 +77,7 @@ void     SWDLLEXPORT SWMgr_setCipherKey(SWHANDLE hmgr, const char *modName, cons
 // SWModule methods
 
 void  SWDLLEXPORT SWModule_terminateSearch(SWHANDLE hmodule);
+SWHANDLE SWDLLEXPORT SWModule_doSearch(SWHANDLE hmodule, const char *searchString, int type, int params,  void (*percent) (char, void *), void *percentUserData);
 char  SWDLLEXPORT SWModule_error(SWHANDLE hmodule);
 int   SWDLLEXPORT SWModule_getEntrySize(SWHANDLE hmodule);
 void  SWDLLEXPORT SWModule_setKeyText(SWHANDLE hmodule, const char *key);
@@ -67,6 +90,13 @@ void  SWDLLEXPORT SWModule_next(SWHANDLE hmodule);
 void  SWDLLEXPORT SWModule_begin(SWHANDLE hmodule);
 const char * SWDLLEXPORT SWModule_getStripText(SWHANDLE hmodule);
 const char * SWDLLEXPORT SWModule_getRenderText(SWHANDLE hmodule);
+const char * SWDLLEXPORT SWModule_getEntryAttributes(SWHANDLE hmodule, const char *level1, const char *level2, const char *level3);
+const char * SWDLLEXPORT SWModule_getPreverseHeader(SWHANDLE hmodule, const char *key, int pvHeading);
+const char * SWDLLEXPORT SWModule_getFootnoteType(SWHANDLE hmodule, const char *key, const char *note);
+const char * SWDLLEXPORT SWModule_getFootnoteBody(SWHANDLE hmodule, const char *key, const char *note);
+const char * SWDLLEXPORT SWModule_getFootnoteRefList(SWHANDLE hmodule, const char *key, const char *note);
+
+SWHANDLE SWDLLEXPORT listkey_getVerselistIterator(const char * list, const char * key);
 
 }
 #ifdef __cplusplus
