@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Id: gbfredletterwords.h,v 1.4 2003/07/05 04:58:42 scribe Exp $
+ * $Id: gbfredletterwords.h 1688 2005-01-01 04:42:26Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -33,7 +33,7 @@ class SWDLLEXPORT GBFRedLetterWords : public SWOptionFilter {
 public:
 	GBFRedLetterWords();
 	virtual ~GBFRedLetterWords();
-	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule * = 0);
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
 };
 
 SWORD_NAMESPACE_END
