@@ -4,7 +4,7 @@
  *				(e.g. verse, word,
  *				place, etc.)
  *
- * $Id: listkey.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: listkey.h 1958 2006-08-22 00:15:10Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -38,86 +38,103 @@ SWORD_NAMESPACE_START
 class SWDLLEXPORT ListKey : public SWKey {
 
 	static SWClass classdef;
-	void init ();
+	void init();
+
 protected:
 	int arraypos;
 	int arraymax;
 	int arraycnt;
 	SWKey **array;
+
 public:
+
 	/** initializes instance of ListKey
-	*
-	* @param ikey text key
-	*/
+	 *
+	 * @param ikey text key
+	 */
 	ListKey(const char *ikey = 0);
 	ListKey(ListKey const &k);
+
 	/** cleans up instance of ListKey
-	*/
-	virtual ~ ListKey();
+	 */
+	virtual ~ListKey();
 
 	virtual SWKey *clone() const;
+	
 	/** Clears out elements of list
-	*/
-	virtual void ClearList();
+	 */
+	virtual void clear();
+
+	/** deprecated, use clear(), instead
+	 */
+	virtual void ClearList() { clear(); }
+
 	/** Returns number of elements in list
-	* @return number of elements in list
-	*/
+	 * @return number of elements in list
+	 */
 	virtual int Count();
+	
 	/** Removes current element from list
-	*/
+	 */
 	virtual void Remove();
+	
 	/** Sets key to element number
-	*
-	* @param ielement element number to set to
-	* @return error status
-	*/
+	 *
+	 * @param ielement element number to set to
+	 * @return error status
+	 */
 	virtual char SetToElement(int ielement, SW_POSITION = TOP);
+	
 	/** Gets a key element number
-	*
-	* @param pos element number to get (or default current)
-	* @return Key or null on error
-	*/
+	 *
+	 * @param pos element number to get (or default current)
+	 * @return Key or null on error
+	 */
 	virtual SWKey *getElement(int pos = -1);
+	
 	// deprecated, use above function
 	virtual SWKey *GetElement(int pos = -1) { return getElement(pos); }
 
 	/** Adds an element to the list
-	* @param ikey the element to add
-	*/
+	 * @param ikey the element to add
+	 */
 	ListKey & operator <<(const SWKey &ikey) { add(ikey); return *this; }
 	virtual void add(const SWKey &ikey);
 
 	/** Equates this ListKey to another ListKey object
-	*
-	* @param ikey other ListKey object
-	*/
+	 *
+	 * @param ikey other ListKey object
+	 */
 	virtual void copyFrom(const ListKey & ikey);
 	virtual void copyFrom(const SWKey & ikey) { SWKey::copyFrom(ikey); }
 
 	/** Positions this key
-	*
-	* @param pos position
-	* @return *this
-	*/
+	 *
+	 * @param pos position
+	 * @return *this
+	 */
 	virtual void setPosition(SW_POSITION pos);
+	
 	/** Decrements a number of elements
-	*/
+	 */
 	virtual void decrement(int step);
+	
 	/** Increments a number of elements
-	*/
+	 */
 	virtual void increment(int step);
 
-	virtual bool isTraversable() { return true; }
+	virtual bool isTraversable() const { return true; }
 	virtual long Index() const { return arraypos; }
 	virtual const char *getRangeText() const;
 
 	/**
-	* Returns the index for the new one given as as parameter.
-	* The first parameter is the new index.
-	*/
-	virtual long Index(long index) { SetToElement (index); return Index (); }
+	 * Returns the index for the new one given as as parameter.
+	 * The first parameter is the new index.
+	 */
+	virtual long Index(long index) { SetToElement(index); return Index (); }
 	virtual const char *getText() const;
 	virtual void setText(const char *ikey);
+	virtual void sort();
 
 	SWKEY_OPERATORS
 	ListKey & operator =(const ListKey &key) { copyFrom(key); return *this; }
