@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: osishtmlhref.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: osishtmlhref.h 1975 2006-09-21 04:29:01Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -30,15 +30,23 @@ SWORD_NAMESPACE_START
 class SWDLLEXPORT OSISHTMLHREF : public SWBasicFilter {
 private:
 protected:
+	// used by derived classes so we have it in the header
+	class QuoteStack;
 	class MyUserData : public BasicFilterUserData {
 	public:
 		bool osisQToTick;
 		bool inBold;
+		bool inName;
+		int suspendLevel;
+		SWBuf wordsOfChristStart;
+		SWBuf wordsOfChristEnd;
+                QuoteStack *quoteStack;
 		SWBuf lastTransChange;
 		SWBuf w;
 		SWBuf fn;
 		SWBuf version;
 		MyUserData(const SWModule *module, const SWKey *key);
+		~MyUserData();
 	};
 	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key) {
 		return new MyUserData(module, key);
