@@ -2,7 +2,7 @@
  *  rawcom.h   - code for class 'RawCom'- a module that reads raw commentary
  *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: rawcom.h 1790 2005-05-03 03:49:04Z scribe $
+ * $Id: rawcom.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -30,9 +30,7 @@
 
 SWORD_NAMESPACE_START
 
-class SWDLLEXPORT RawCom:public RawVerse, public SWCom {
-
-	VerseKey &getVerseKey();
+class SWDLLEXPORT RawCom : public RawVerse, public SWCom {
 
 
 public:
@@ -49,9 +47,7 @@ public:
 	virtual void decrement(int steps) { increment(-steps); }
 
 	// write interface ----------------------------
-	virtual bool isWritable() {
-		return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & FileMgr::RDWR) == FileMgr::RDWR));
-	}
+	virtual bool isWritable();
 	static char createModule(const char *path) { return RawVerse::createModule(path); }
 	virtual void setEntry(const char *inbuf, long len = -1);	// Modify current module entry
 	virtual void linkEntry(const SWKey *linkKey);	// Link current module entry to other module entry
