@@ -2,7 +2,7 @@
  *  rawtext.h   - code for class 'RawText'- a module that reads raw text files:
  *		  ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: rawgenbook.h,v 1.7 2003/02/26 04:49:12 scribe Exp $
+ * $Id: rawgenbook.h 1917 2006-05-22 01:07:17Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,15 +24,17 @@
 #define RAWGENBOOK_H
 
 #include <swgenbook.h>
-#include <filemgr.h>
 
 #include <defs.h>
 
 SWORD_NAMESPACE_START
 
+class FileDesc;
+
 class SWDLLEXPORT RawGenBook : public SWGenBook {
 	char *path;
 	FileDesc *bdtfd;
+	bool verseKey;
 
 public:
   
@@ -40,13 +42,11 @@ public:
 	RawGenBook(const char *ipath, const char *iname = 0, const char *idesc = 0,
 			SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
 			SWTextDirection dir = DIRECTION_LTR,
-			SWTextMarkup markup = FMT_UNKNOWN, const char* ilang = 0);
+			SWTextMarkup markup = FMT_UNKNOWN, const char* ilang = 0, const char *keyType = "TreeKey");
 	virtual ~RawGenBook();
 	virtual SWBuf &getRawEntryBuf();
 	// write interface ----------------------------
-	virtual bool isWritable() {
-		return ((bdtfd->getFd() > 0) && ((bdtfd->mode & O_RDWR) == O_RDWR));
-	}
+	virtual bool isWritable();
 	static char createModule(const char *ipath);
 	virtual void setEntry(const char *inbuf, long len = -1);	// Modify current module entry
 	virtual void linkEntry(const SWKey * linkKey);	// Link current module entry to other module entry
