@@ -4,7 +4,7 @@
  *			and provides lookup and parsing functions based on
  *			class StrKey
  *
- * $Id: rawstr.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: rawstr.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -26,11 +26,12 @@
 #define RAWSTR_H
 
 #include <defs.h>
-#include <filemgr.h>
-#include <swbuf.h>
 
 SWORD_NAMESPACE_START
 
+class SWBuf;
+class FileDesc;
+
 class SWDLLEXPORT RawStr {
 	static int instance;		// number of instantiated RawStr objects or derivitives
 	char *path;
