@@ -2,7 +2,7 @@
  *  swcom.h   - code for base class 'SWCom'.  SWCom is the basis for all
  *		 types of commentary modules
  *
- * $Id: swcom.h,v 1.13 2003/02/28 13:12:43 mgruner Exp $
+ * $Id: swcom.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,15 +24,24 @@
 #define SWCOM_H
 
 #include <swmodule.h>
-#include <versekey.h>
 
 #include <defs.h>
 
 SWORD_NAMESPACE_START
 
+class VerseKey;
+class SWKey;
+
   /** The basis for all commentary modules
   */
 class SWDLLEXPORT SWCom : public SWModule {
+
+	mutable VerseKey *tmpVK;
+
+protected:
+	VerseKey &getVerseKey() const;
+
+
 public:
 
 	/** Initializes data for instance of SWCom
@@ -43,7 +52,7 @@ public:
 			SWTextMarkup mark = FMT_UNKNOWN, const char* ilang = 0);
 
 	virtual ~SWCom();
-	virtual SWKey *CreateKey() { return new VerseKey(); }
+	virtual SWKey *CreateKey();
 
 	virtual long Index() const;
 	virtual long Index(long iindex);
