@@ -3,7 +3,7 @@
  *				types of keys for indexing into modules (e.g. verse, word,
  *				place, etc.)
  *
- * $Id: swkey.h 1819 2005-05-28 07:07:40Z scribe $
+ * $Id: swkey.h 1958 2006-08-22 00:15:10Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -170,14 +170,13 @@ public:
 	 */
 	virtual void increment(int steps = 1);
 
-	/** Increments key a number of entries
-	 * deprecated, use isTraversible
+	/** deprecated, use isTraversible
 	 */
 	char Traversable() { return (isTraversable()) ? 1:0; }
 
 	/** Whether or not this key can be ++ -- incremented
 	 */
-	virtual bool isTraversable() { return false; }
+	virtual bool isTraversable() const { return false; }
 
 	/** Use this function to get an index position within a module.
 	 * Here's a small example how to use this function and @ref Index(long).
