@@ -2,7 +2,7 @@
  *  swmgr.h   - definition of class SWMgr used to interact with an install
  *				base of sword modules.
  *
- * $Id: swmgr.h 1819 2005-05-28 07:07:40Z scribe $
+ * $Id: swmgr.h 1971 2006-09-05 01:59:48Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -51,34 +51,42 @@
 #ifndef SWMGR_H
 #define SWMGR_H
 
-#include <sys/types.h>
 #include <map>
 #include <list>
-#include <swmodule.h>
+#include <swbuf.h>
 #include <swconfig.h>
-#include <swlog.h>
-#include <swfiltermgr.h>
 
 #include <defs.h>
 
 SWORD_NAMESPACE_START
 
+class SWModule;
+class SWFilter;
+class SWOptionFilter;
+class SWFilterMgr;
+class SWBuf;
+class SWKey;
+
 typedef std::map < SWBuf, SWModule *, std::less < SWBuf > >ModMap;
 typedef std::map < SWBuf, SWFilter * >FilterMap;
+typedef std::map < SWBuf, SWOptionFilter * >OptionFilterMap;
 typedef std::list < SWBuf >StringList;
+typedef std::list < SWFilter* >FilterList;
+typedef std::list < SWOptionFilter* >OptionFilterList;
+
+class FileDesc;
+class SWOptionFilter;
 
 /** SWMgr exposes an installed module set
  *
  * SWMgr exposes an installed module set and can be asked to configure the desired
  *	markup and options which modules will produce.
  *
- * @version $Id: swmgr.h 1819 2005-05-28 07:07:40Z scribe $
+ * @version $Id: swmgr.h 1971 2006-09-05 01:59:48Z scribe $
  */
-
-class FileDesc;
-
 class SWDLLEXPORT SWMgr {
 
+
 private:
 	bool mgrModeMultiMod;
 	bool augmentHome;
@@ -90,15 +98,16 @@ protected:
 	SWConfig *mysysconfig;
 	SWConfig *homeConfig;
 	void CreateMods(bool multiMod = false);
-	SWModule *CreateMod(const char *name, const char *driver, ConfigEntMap & section);
+	SWModule *CreateMod(const char *name, const char *driver, ConfigEntMap &section);
 	void DeleteMods();
 	char configType;		// 0 = file; 1 = directory
-	FilterMap optionFilters;
+	OptionFilterMap optionFilters;
 	FilterMap cipherFilters;
 	SWFilter *gbfplain;
 	SWFilter *thmlplain;
 	SWFilter *osisplain;
-	SWFilter *transliterator;
+	SWFilter *teiplain;
+	SWOptionFilter *transliterator;
 	FilterList cleanupFilters;
 	StringList options;
 	virtual void init(); // use to initialize before loading modules
@@ -132,6 +141,9 @@ protected:
 	 */
 	virtual void AddStripFilters(SWModule *module, ConfigEntMap &section);
 
+	// ones manually specified in .conf file
+	virtual void AddStripFilters(SWModule *module, ConfigEntMap &section, ConfigEntMap::iterator start, ConfigEntMap::iterator end);
+
 	/**
 	 * Called to add appropriate Raw Filters to a module.  Override to do special actions,
 	 *	if desired.	See the module.conf CipherKey= entry.
@@ -155,7 +167,7 @@ public:
 	/**
 	 *
 	 */
-	static void findConfig(char *configType, char **prefixPath, char **configPath, StringList *augPaths = 0);
+	static void findConfig(char *configType, char **prefixPath, char **configPath, StringList *augPaths = 0, SWConfig *providedSysConf = 0);
 
 	SWConfig *config;
 	SWConfig *sysconfig;
@@ -212,7 +224,7 @@ public:
 	 *	For example, this will create an SWMgr and cause its modules to produce HTMLHREF formatted output
 	 *	when asked for renderable text:
 	 *
-	 *	SWMgr *myMgr = new SWMgr(0, 0, false, new MarkupFilterMgr(FMT_HTMLHREF));
+	 *	SWMgr *myMgr = new SWMgr(0, 0, true, new MarkupFilterMgr(FMT_HTMLHREF));
 	 */
 	SWMgr(SWConfig *iconfig = 0, SWConfig *isysconfig = 0, bool autoload = true, SWFilterMgr *filterMgr = 0, bool multiMod = false);
 
@@ -289,6 +301,15 @@ public:
 	 */
 	virtual StringList getGlobalOptionValues(const char *option);
 
+	/** Filters a buffer thru a named filter
+	 * @param filterName
+	 * @param text buffer to filter
+	 * @param key context key if filter needs this for processing
+	 * @param module context module if filter needs this for processing
+	 * @return error status
+	 */
+	virtual char filterText(const char *filterName, SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
+
 	/**
 	 * Sets the cipher key for the given module. This function updates the key
 	 * at runtime, but it does not write to the config file.
