@@ -2,7 +2,7 @@
  *  swsearchable.h	- definition of class SWSearchable used to provide an
  *	interface for objects that be searched.
  *
- * $Id: swsearchable.h 1715 2005-02-08 10:06:35Z scribe $
+ * $Id: swsearchable.h 1872 2005-12-17 23:45:01Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,10 +24,12 @@
 #define SWSEARCHABLE_H
 
 #include <defs.h>
-#include <listkey.h>
 
 SWORD_NAMESPACE_START
 
+class ListKey;
+class SWKey;
+
 /** used to provide an interface for objects that be searched.
  */
 class SWDLLEXPORT SWSearchable {
@@ -83,11 +85,7 @@ public:
 	* This function checks whether the search framework may work in the best way.
 	* @return True if the the search is optimally supported, false if it's not working in the best way.
 	*/
-	virtual bool isSearchOptimallySupported(const char *istr, int searchType, int flags, SWKey * scope) {
-		bool retVal = false;
-		search(istr, searchType, flags, scope, &retVal);
-		return retVal;
-	}
+	virtual bool isSearchOptimallySupported(const char *istr, int searchType, int flags, SWKey *scope);
 };
 
 SWORD_NAMESPACE_END
