@@ -2,7 +2,7 @@
  *  swtext.h   - code for base class 'SWText'.  SWText is the basis for all
  *		 types of text modules
  *
- * $Id: swtext.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: swtext.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,16 +24,23 @@
 #define SWTEXT_H
 
 #include <swmodule.h>
-#include <versekey.h>
-#include <listkey.h>
 
 #include <defs.h>
 
 SWORD_NAMESPACE_START
 
+class VerseKey;
+
 /** The basis for all text modules
  */
 class SWDLLEXPORT SWText : public SWModule {
+
+	// for conversion if we have been set with a different internal key type
+	mutable VerseKey *tmpVK;
+
+protected:
+	VerseKey &getVerseKey() const;
+	
 public:
 	/** Initializes data for instance of SWText
 	*/
