@@ -1,7 +1,7 @@
 /******************************************************************************
  *  versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: treekey.h 1728 2005-02-23 13:49:32Z mgruner $
+ * $Id: treekey.h 1958 2006-08-22 00:15:10Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,7 +24,7 @@
 #define TREEKEY_H
 
 #include <swkey.h>
-#include <swmacs.h>
+#include <swbuf.h>
 
 #include <defs.h>
 
@@ -38,6 +38,12 @@ class SWDLLEXPORT TreeKey : public SWKey {
 	static SWClass classdef;
 	void init();
 
+protected:
+	// hold on to setText until we've done a snap action: getText or navigation
+	// if we set, and then write out userData, we want to assure the path exists.
+	// This better conforms to the SWORD write methodology: mod.setKey, mod.setEntry
+	mutable SWBuf unsnappedKeyText;
+
 public:
 //	TreeKey (const char *ikey = 0);
 //	TreeKey (const SWKey * ikey);
@@ -52,15 +58,33 @@ public:
 	virtual const char *getUserData(int *size = 0) = 0;
 	virtual void setUserData(const char *userData, int size = 0) = 0;
 
-	virtual const char *getFullName() const = 0;
-
+	/** Go to the root node
+	*/
 	virtual void root() = 0;
+
+	/** Go to the parent of the current node
+	* @return success or failure
+	*/
 	virtual bool parent() = 0;
 
+	/** Go to the first child of the current node
+	* @return success or failure
+	*/
 	virtual bool firstChild() = 0;
+
+	/** Go to the next sibling of the current node
+	* @return success or failure
+	*/
 	virtual bool nextSibling() = 0;
+
+	/** Go to the previous sibling of the current node
+	* @return success or failure
+	*/
 	virtual bool previousSibling() = 0;
 
+	/** Does the current node have children?
+	* @return whether or not it does
+	*/
 	virtual bool hasChildren() = 0;
 
 	virtual void append() = 0;
@@ -69,6 +93,7 @@ public:
 
 	virtual void remove() = 0;
 
+
 	virtual void setOffset(unsigned long offset) = 0;
 	virtual unsigned long getOffset() const = 0;
 
@@ -78,9 +103,16 @@ public:
 	virtual int compare(const SWKey &ikey) = 0;
 	virtual void decrement(int steps = 1) = 0;
 	virtual void increment(int steps = 1) = 0;
-	virtual bool isTraversable() { return true; }
-	virtual long Index () const { return getOffset(); }
-	virtual long Index (long iindex) { setOffset(iindex); return getOffset(); }
+	virtual bool isTraversable() const { return true; }
+	virtual long Index() const { return getOffset(); }
+	virtual long Index(long iindex) { setOffset(iindex); return getOffset(); }
+
+	/** Set the key to this path.  If the path doesn't exist, then
+	 *	nodes are created as necessary
+	 * @keyPath = path to set/create; if unsupplied, then use any unsnapped setText value.
+	 */
+	virtual void assureKeyPath(const char *keyPath = 0);
+	virtual void save() {}
 
 	SWKEY_OPERATORS
 
