@@ -1,7 +1,7 @@
 /******************************************************************************
  *  versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: treekeyidx.h 1728 2005-02-23 13:49:32Z mgruner $
+ * $Id: treekeyidx.h 1958 2006-08-22 00:15:10Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -25,10 +25,11 @@
 
 #include <treekey.h>
 #include <sysdata.h>
-#include <filemgr.h>
 
 SWORD_NAMESPACE_START
 
+class FileDesc;
+
 /**
  * Class TreeKeyIdx
  * The TreeKey implementation used for all tree-based modules in Sword, such as GenBooks.
@@ -75,8 +76,6 @@ public:
 	virtual const char *getUserData(int *size = 0);
 	virtual void setUserData(const char *userData, int size = 0);
 
-	virtual const char *getFullName() const;
-
 	virtual void root();
 	virtual bool parent();
 
@@ -94,13 +93,12 @@ public:
 	virtual void save();
 
 	virtual void copyFrom(const TreeKeyIdx &ikey);
-	virtual void copyFrom(const SWKey & ikey);
+	virtual void copyFrom(const SWKey &ikey);
 
 	void setOffset(unsigned long offset);
 	unsigned long getOffset() const;
 
 
-
 	// OPERATORS ------------------------------------------------------------
 
 
@@ -114,7 +112,7 @@ public:
 	virtual int compare(const SWKey &ikey);
 	virtual void decrement(int steps = 1);
 	virtual void increment(int steps = 1);
-	virtual bool isTraversable() { return true; }
+	virtual bool isTraversable() const { return true; }
 
 	static signed char create(const char *path);
 };
