@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: utf8transliterator.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: utf8transliterator.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 2001 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -25,8 +25,7 @@ enum scriptEnum {SE_OFF, SE_LATIN, /*one-way (to) transliterators*/  SE_IPA, SE_
 #define NUMSCRIPTS 50
 #define NUMTARGETSCRIPTS NUMSCRIPTS-3//6
 
-#include <swfilter.h>
-#include <swmodule.h>
+#include <swoptfilter.h>
 
 #include <unicode/unistr.h>
 
@@ -37,11 +36,13 @@ enum scriptEnum {SE_OFF, SE_LATIN, /*one-way (to) transliterators*/  SE_IPA, SE_
 
 SWORD_NAMESPACE_START
 
+class SWModule;
+
 struct SWTransData {
 	UnicodeString resource;
 	UTransDirection dir;
 };
-typedef std::map <const UnicodeString, SWTransData> SWTransMap;
+typedef std::map<const UnicodeString, SWTransData> SWTransMap;
 typedef std::pair<UnicodeString, SWTransData> SWTransPair;
 
 // Chris, please add more javadoc-style documentation in this header file
@@ -50,7 +51,7 @@ typedef std::pair<UnicodeString, SWTransData> SWTransPair;
 
 /** This Filter uses ICU for transliteration
 */
-class SWDLLEXPORT UTF8Transliterator : public SWFilter {
+class SWDLLEXPORT UTF8Transliterator : public SWOptionFilter {
 private:
 
 	char option;
