@@ -1,7 +1,7 @@
 /******************************************************************************
  *  utilxml.h   - definition of class that deal with xml constructs 
  *
- * $Id: utilxml.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: utilxml.h 1952 2006-07-30 19:08:20Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -65,12 +65,16 @@ public:
 		if (!parsed)
 			parse();
 		empty = value;
+		if (value)
+			endTag = false;
 	}
 
 	inline bool isEndTag() const { return endTag; }
 
 	const StringList getAttributeNames() const;
 	int getAttributePartCount(const char *attribName, char partSplit = '|') const;
+
+	// return values should not be considered to persist beyond the return of the function.
 	const char *getAttribute(const char *attribName, int partNum = -1, char partSplit = '|') const;
 	const char *setAttribute(const char *attribName, const char *attribValue);
 	const char *toString() const;
