@@ -1,7 +1,7 @@
 /******************************************************************************
  *	versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: versekey.h 1804 2005-05-07 06:26:10Z scribe $
+ * $Id: versekey.h 1958 2006-08-22 00:15:10Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -26,7 +26,6 @@
 #include <swkey.h>
 #include <swmacs.h>
 #include <listkey.h>
-#include <ctype.h>
 
 #include <defs.h>
 
@@ -72,7 +71,8 @@ class SWLocale;
  * Class VerseKey
  * The SWKey implementation used for verse based modules like Bibles or commentaries.
  */
-class SWDLLEXPORT VerseKey:public SWKey {
+class SWDLLEXPORT VerseKey : public SWKey {
+
 	class LocaleCache {
 	public:
 		char *name;
@@ -114,36 +114,33 @@ class SWDLLEXPORT VerseKey:public SWKey {
 	const struct abbrev *abbrevs;
 	char *locale;
 	int abbrevsCnt;
+
 	/** The Testament: 0 - Old; 1 - New
 	*/
 	signed char testament;
 	mutable signed char book;
 	mutable signed int chapter;
 	mutable signed int verse;
+
 	/** flag for auto normalization 
 	*/
 	char autonorm;
+
 	/** flag for headings on/off
 	*/
 	char headings;
 
 	int getBookAbbrev(const char *abbr);
 	void initBounds() const;
+
 	/** initialize and allocate books array
 	*/
 	void initstatics();
+
 	/** initializes this VerseKey()
 	*/
 	void init();
-	/** Refresh keytext based on testament|book|chapter|verse
-	* default auto normalization to true
-	* default display headings option is false
-	*/
-	void freshtext() const;
-	/**	Parse a character array into testament|book|chapter|verse 
-	*
-	*/
-	virtual char parse();
+
 	/** Binary search to find the index closest, but less
 	* than the given value.
 	*
@@ -153,8 +150,21 @@ class SWDLLEXPORT VerseKey:public SWKey {
 	* @return the index into the array that is less than but closest to value
 	*/
 	int findindex(long *array, int size, long value);
+
 	mutable VerseKey *lowerBound, *upperBound;
 
+
+protected:
+
+	/** Refresh keytext based on testament|book|chapter|verse
+	* default auto normalization to true
+	* default display headings option is false
+	*/
+	void freshtext() const;
+	/**	Parse a character array into testament|book|chapter|verse 
+	*
+	*/
+	virtual char parse();
 public:
 #if 0
 	static long otbks[];
@@ -244,11 +254,11 @@ public:
 	virtual const char *getText() const;
 	virtual const char *getShortText() const;
 	virtual void setText(const char *ikey) { SWKey::setText(ikey); parse (); }
-	virtual void copyFrom(const SWKey & ikey);
+	virtual void copyFrom(const SWKey &ikey);
 	
 	/** Equates this VerseKey to another VerseKey
 	*/
-	virtual void copyFrom(const VerseKey & ikey);
+	virtual void copyFrom(const VerseKey &ikey);
 	
 	/** Positions this key
 	*
@@ -270,7 +280,7 @@ public:
 	* @return *this
 	*/
 	virtual void increment(int steps);
-	virtual bool isTraversable() { return true; }
+	virtual bool isTraversable() const { return true; }
 
 	virtual const char *getBookName() const;
 	virtual const char *getBookAbbrev() const;
@@ -350,7 +360,7 @@ public:
 	* @return if unchanged -> value of autonorm,
 	* if changed -> previous value of autonorm
 	*/
-	virtual char AutoNormalize(char iautonorm = MAXPOS (char));
+	virtual char AutoNormalize(char iautonorm = MAXPOS(char));
 	
 	/** Sets/gets flag that tells VerseKey to include
 	* chapter/book/testament/module headings
@@ -360,7 +370,7 @@ public:
 	* @return if unchanged -> value of headings,
 	* if changed -> previous value of headings
 	*/
-	virtual char Headings(char iheadings = MAXPOS (char));
+	virtual char Headings(char iheadings = MAXPOS(char));
 	
 	virtual long NewIndex() const;
 	
