@@ -2,7 +2,7 @@
  *  zcom.h   - code for class 'zCom'- a module that reads compressed text
  *				files: ot and nt using indexs ??.vss
  *
- * $Id: zcom.h 1790 2005-05-03 03:49:04Z scribe $
+ * $Id: zcom.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,20 +23,17 @@
 #ifndef ZCOM_H
 #define ZCOM_H
 
-#include <rawverse.h>
 #include <swcom.h>
-#include <swcomprs.h>
 
 #include <defs.h>
 
 SWORD_NAMESPACE_START
 
-class SWDLLEXPORT zCom:public zVerse, public SWCom {
+class SWDLLEXPORT zCom : public zVerse, public SWCom {
 
 	VerseKey *lastWriteKey;
 	bool sameBlock(VerseKey * lastWriteKey, VerseKey * key);
 	int blockType;
-	VerseKey &getVerseKey();
 
 
 public:
@@ -52,9 +49,7 @@ public:
 	virtual void decrement(int steps = 1) { increment(-steps); }
 
 	// write interface ----------------------------
-	virtual bool isWritable() {
-		return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & FileMgr::RDWR) == FileMgr::RDWR));
-	}
+	virtual bool isWritable();
 	static char createModule(const char *path, int blockBound) {
 		return zVerse::createModule(path, blockBound);
 	}
