@@ -4,7 +4,7 @@
  *			and provides lookup and parsing functions based on
  *			class StrKey
  *
- * $Id: zstr.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: zstr.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -25,14 +25,14 @@
 #ifndef ZSTR_H
 #define ZSTR_H
 
-#include <filemgr.h>
-#include <swbuf.h>
 #include <defs.h>
 
 SWORD_NAMESPACE_START
 
 class SWCompress;
 class EntriesBlock;
+class FileDesc;
+class SWBuf;
 
 class SWDLLEXPORT zStr {
 
