@@ -8,6 +8,7 @@
 #include <stdlib.h>
 #include <swkey.h>
 #include <listkey.h>
+#include <string.h>
 
 SWORD_NAMESPACE_START
 
@@ -62,7 +63,7 @@ ListKey::~ListKey()
  * ListKey::ClearList	- Clears out elements of list
  */
 
-void ListKey::ClearList()
+void ListKey::clear()
 {
 	int loop;
 
@@ -315,5 +316,18 @@ void ListKey::setText(const char *ikey) {
 	SWKey::setText(ikey);
 }
 
+// This sort impl sucks.  Let's change it to a quicksort or some other efficient algol
+void ListKey::sort() {
+	for (int i = 0; i < arraycnt; i++) {
+		for (int j = i; j < arraycnt; j++) {
+			if (*array[j] < *array[i]) {
+				SWKey *tmp = array[i];
+				array[i] = array[j];
+				array[j] = tmp;
+			}
+		}
+	}
+}
+
 SWORD_NAMESPACE_END
 
