@@ -1,7 +1,7 @@
 /******************************************************************************
  *  versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: treekeyidx.cpp 1790 2005-05-03 03:49:04Z scribe $
+ * $Id: treekeyidx.cpp 1896 2006-02-13 09:29:56Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -27,6 +27,8 @@
 
 #include <swlog.h>
 #include <utilstr.h>
+#include <filemgr.h>
+#include <swbuf.h>
 
 SWORD_NAMESPACE_START
 
@@ -84,11 +86,13 @@ TreeKeyIdx::~TreeKeyIdx () {
 
 
 const char *TreeKeyIdx::getLocalName() {
+	unsnappedKeyText = "";
 	return currentNode.name;
 }
 
 
 const char *TreeKeyIdx::getUserData(int *size) {
+	unsnappedKeyText = "";
 	if (size)
 		*size = (int)currentNode.dsize;
 	return currentNode.userData;
@@ -96,6 +100,8 @@ const char *TreeKeyIdx::getUserData(int *size) {
 
 
 void TreeKeyIdx::setUserData(const char *userData, int size) {
+	// this makes sure any unsnapped path exists
+	assureKeyPath();
 	if (currentNode.userData)
 		delete currentNode.userData;
 
@@ -108,6 +114,7 @@ void TreeKeyIdx::setUserData(const char *userData, int size) {
 }
 
 const char *TreeKeyIdx::setLocalName(const char *newName) {
+	unsnappedKeyText = "";
 	stdstr(&(currentNode.name), newName);
 	return currentNode.name;
 }
@@ -118,19 +125,6 @@ void TreeKeyIdx::save() {
 }
 
 
-const char *TreeKeyIdx::getFullName() const {
-	TreeNode parent;
-	static SWBuf fullPath;
-	fullPath = currentNode.name;
-	parent.parent = currentNode.parent;
-	while (parent.parent > -1) {
-		getTreeNodeFromIdxOffset(parent.parent, &parent);
-		fullPath = ((SWBuf)parent.name) + (SWBuf) "/" + fullPath;
-	}
-	return fullPath.c_str();
-}
-
-
 void TreeKeyIdx::root() {
 	error = getTreeNodeFromIdxOffset(0, &currentNode);
 }
@@ -279,6 +273,7 @@ signed char TreeKeyIdx::create(const char *ipath) {
  */
 
 void TreeKeyIdx::getTreeNodeFromDatOffset(long ioffset, TreeNode *node) const {
+	unsnappedKeyText = "";
 	char ch;
 	__s32  tmp;
 	__u16  tmp2;
@@ -327,6 +322,7 @@ void TreeKeyIdx::getTreeNodeFromDatOffset(long ioffset, TreeNode *node) const {
  */
 
 char TreeKeyIdx::getTreeNodeFromIdxOffset(long ioffset, TreeNode *node) const {
+	unsnappedKeyText = "";
 	__u32 offset;
 	char error = KEYERR_OUTOFBOUNDS;
 	
@@ -358,6 +354,7 @@ char TreeKeyIdx::getTreeNodeFromIdxOffset(long ioffset, TreeNode *node) const {
 
 
 unsigned long TreeKeyIdx::getOffset() const {
+	unsnappedKeyText = "";
 	return currentNode.offset;
 }
 
@@ -367,6 +364,7 @@ void TreeKeyIdx::setOffset(unsigned long offset) {
 
 
 void TreeKeyIdx::saveTreeNodeOffsets(TreeNode *node) {
+	unsnappedKeyText = "";
 	long datOffset = 0;
 	__s32 tmp;
 
@@ -395,6 +393,7 @@ void TreeKeyIdx::saveTreeNodeOffsets(TreeNode *node) {
 
 
 void TreeKeyIdx::copyFrom(const TreeKeyIdx &ikey) {
+	unsnappedKeyText = "";
 
 	SWKey::copyFrom(ikey);
 
@@ -481,11 +480,13 @@ void TreeKeyIdx::setText(const char *ikey) {
 		}
 	}
 	delete [] buf;
+	unsnappedKeyText = ikey;
 }
 
 
 
 void TreeKeyIdx::copyFrom(const SWKey &ikey) {
+	unsnappedKeyText = ikey;
 	SWKey::copyFrom(ikey);
 }
 
@@ -501,10 +502,6 @@ void TreeKeyIdx::setPosition(SW_POSITION p) {
 	Error();	// clear error from normalize
 }
 
-const char *TreeKeyIdx::getText() const {
-	return getFullName();
-}
-
 
 int TreeKeyIdx::_compare (const TreeKeyIdx & ikey) {
 		return (getOffset() - ikey.getOffset());
@@ -547,6 +544,21 @@ void TreeKeyIdx::increment(int steps) {
 
 
 
+const char *TreeKeyIdx::getText() const {
+	TreeNode parent;
+	static SWBuf fullPath;
+	fullPath = currentNode.name;
+	parent.parent = currentNode.parent;
+	while (parent.parent > -1) {
+		getTreeNodeFromIdxOffset(parent.parent, &parent);
+		fullPath = ((SWBuf)parent.name) + (SWBuf) "/" + fullPath;
+	}
+	// we've snapped; clear our unsnapped text holder
+	unsnappedKeyText = "";
+	return fullPath.c_str();
+}
+
+
 TreeKeyIdx::TreeNode::TreeNode() {
 
 	name       = 0;
