@@ -6,6 +6,7 @@
 #include <stdio.h>
 #include <fcntl.h>
 #include <stdlib.h>
+#include <ctype.h>
 
 #include <utilstr.h>
 #include <stringmgr.h>
@@ -13,6 +14,7 @@
 #include <swlog.h>
 #include <versekey.h>
 #include <localemgr.h>
+#include <swlocale.h>
 #include <roman.h>
 
 SWORD_NAMESPACE_START
@@ -188,19 +190,32 @@ void VerseKey::setBookAbbrevs(const struct abbrev *bookAbbrevs, unsigned int siz
 			}
 			*/
 		}
-        
+
 		if (SWLog::getSystemLog()->getLogLevel() > 0) { //make sure log is wanted, this loop stuff costs a lot of time
 			for (int t = 0; t < 2; t++) {
 				for (int i = 0; i < BMAX[t]; i++) {
 					const int bn = getBookAbbrev(books[t][i].name);
 					if ((bn-1)%39 != i) {
-						SWLog::getSystemLog()->logError("VerseKey::Book: %s does not have a matching toupper abbrevs entry! book number returned was: %d(%d)", 
+						SWLog::getSystemLog()->logError("VerseKey::Book: %s does not have a matching toupper abbrevs entry! book number returned was: %d(%d). Required entry should be:",
 							books[t][i].name, bn, i);
+						char *abbr = 0;
+						stdstr(&abbr, books[t][i].name, 2);
+						strstrip(abbr);
+
+						StringMgr* stringMgr = StringMgr::getSystemStringMgr();
+						const bool hasUTF8Support = StringMgr::hasUTF8Support();
+						if (hasUTF8Support) { //we have support for UTF-8 handling; we expect UTF-8 encoded locales
+							stringMgr->upperUTF8(abbr, strlen(abbr)*2);
+						}
+						else {
+							stringMgr->upperLatin1(abbr);
+						}
+						SWLog::getSystemLog()->logError("%s=%d", abbr, (t*39)+i+1);
 					}
 				}
 			}
 		}
-    	}
+		}
 	else abbrevsCnt = size;
 }
 
@@ -320,23 +335,25 @@ int VerseKey::getBookAbbrev(const char *iabbr)
 
 	StringMgr* stringMgr = StringMgr::getSystemStringMgr();
 	const bool hasUTF8Support = StringMgr::hasUTF8Support();
-	
+
+		// TODO: Why do we loop twice?  once upper and once not?
+		// If you wrote this, please comment.
 	for (int i = 0; i < 2; i++) {
-		stdstr(&abbr, iabbr);
+		stdstr(&abbr, iabbr, 2);
 		strstrip(abbr);
 		if (!i && hasUTF8Support) { //we have support for UTF-8 handling; we expect UTF-8 encoded locales
-			abbr = stringMgr->upperUTF8(abbr);
+			abbr = stringMgr->upperUTF8(abbr, strlen(abbr)*2);
 		}
 		else if (!i) {
 			abbr = stringMgr->upperLatin1(abbr);
 		}
-			
+
 		abLen = strlen(abbr);
 
 		if (abLen) {
 			min = 0;
-			max 	= abbrevsCnt;
-			
+			max = abbrevsCnt;
+
 			while(1) {
 				target = min + ((max - min) / 2);
 				diff = strncmp(abbr, abbrevs[target].ab, abLen);
@@ -346,12 +363,12 @@ int VerseKey::getBookAbbrev(const char *iabbr)
 					min = target;
 				else	max = target;
 			}
-			
+
 			for (; target > 0; target--) {
 				if (strncmp(abbr, abbrevs[target-1].ab, abLen))
 					break;
 			}
-				
+
 			retVal = (!diff) ? abbrevs[target].book : -1;
 		}
 		if (retVal > 0)
@@ -361,6 +378,7 @@ int VerseKey::getBookAbbrev(const char *iabbr)
 	return retVal;
 }
 
+
 /******************************************************************************
  * VerseKey::ParseVerseList - Attempts to parse a buffer into separate
  *				verse entries returned in a ListKey
@@ -1039,7 +1057,7 @@ void VerseKey::Normalize(char autocheck)
 	if ((autocheck) && (!autonorm))	// only normalize if we were explicitely called or if autonorm is turned on
 		return;
 
-	if ((headings) && (!verse))		// this is cheeze and temporary until deciding what actions should be taken.
+	if ((headings) && ((!verse) || (!chapter)))		// this is cheeze and temporary until deciding what actions should be taken.
 		return;					// so headings should only be turned on when positioning with Index() or incrementors
 
 	while ((testament < 3) && (testament > 0)) {
@@ -1456,7 +1474,12 @@ long VerseKey::Index(long iindex)
 
 int VerseKey::compare(const SWKey &ikey)
 {
-	VerseKey ivkey = (const char *)ikey;
+	const SWKey *testKey = &ikey;
+	const VerseKey *vkey = (const VerseKey *)SWDYNAMIC_CAST(VerseKey, testKey);
+	if (vkey) {
+		return _compare(*vkey);
+	}
+	const VerseKey ivkey = (const char *)ikey;
 	return _compare(ivkey);
 }
 
