@@ -2,7 +2,7 @@
  *  filemgr.cpp	- implementation of class FileMgr used for pooling file
  *  					handles
  *
- * $Id: filemgr.cpp 1799 2005-05-06 05:27:12Z scribe $
+ * $Id: filemgr.cpp 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -29,6 +29,7 @@
 #include <sys/types.h>
 #include <stdio.h>
 #include <string.h>
+#include <swbuf.h>
 #if !defined(__GNUC__) && !defined(_WIN32_WCE)
 #include <io.h>
 #include <direct.h>
@@ -458,9 +459,11 @@ char FileMgr::getLine(FileDesc *fDesc, SWBuf &line) {
 		if (!more) {
 			for (; end > start; end--) {
 				if ((chunk[end] != 10) && (chunk[end] != 13) && (chunk[end] != ' ') && (chunk[end] != '\t')) {
-					if (chunk[end] == '\\')
+					if (chunk[end] == '\\') {
 						more = true;
-					else break;
+						end--;
+					}
+					break;
 				}
 			}
 		}
