@@ -2,7 +2,7 @@
  *  localemgr.cpp - implementation of class LocaleMgr used to interact with
  *				registered locales for a sword installation
  *
- * $Id: localemgr.cpp 1790 2005-05-03 03:49:04Z scribe $
+ * $Id: localemgr.cpp 1956 2006-08-16 12:04:50Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -33,10 +33,19 @@
 #include <stringmgr.h>
 #include <filemgr.h>
 #include <localemgr.h>
+#include <swlocale.h>
+#include <swlog.h>
+
+
+#ifdef _MSC_VER
+#define DEBUGSTR(x)
+#else
+#include<iostream>
+#define DEBUGSTR(x) if (SWMgr::debug) std::cerr << x;
+#endif  
 
 SWORD_NAMESPACE_START
 
-
 LocaleMgr *LocaleMgr::systemLocaleMgr = 0;
 
 class __staticsystemLocaleMgr {
@@ -71,8 +80,11 @@ LocaleMgr::LocaleMgr(const char *iConfigPath) {
 	
 	defaultLocaleName = 0;
 	
-	if (!iConfigPath)
+	if (!iConfigPath) {
+		DEBUGSTR("LOOKING UP LOCALE DIRECTORY...\n");
 		SWMgr::findConfig(&configType, &prefixPath, &configPath, &augPaths);
+		DEBUGSTR("LOOKING UP LOCALE DIRECTORY COMPLETE.\n\n");
+	}
 	else configPath = (char *)iConfigPath;
 	
 	if (prefixPath) {
@@ -232,12 +244,11 @@ void LocaleMgr::setDefaultLocaleName(const char *name) {
 	strtok(tmplang, ".");
 	// also discard after '@' so e.g. @euro locales are found
 	strtok(tmplang, "@");
-	// Before we set it we want to verify that it is an existing locale
+
+	stdstr(&defaultLocaleName, tmplang);
+
 	// First check for what we ask for
-	if (getLocale(tmplang)) {
-		stdstr(&defaultLocaleName, tmplang);
-	}
-	else {
+	if (!getLocale(tmplang)) {
 		// check for locale without country
 		char *nocntry=0;
 		stdstr(&nocntry, tmplang);
@@ -245,14 +256,6 @@ void LocaleMgr::setDefaultLocaleName(const char *name) {
 		if (getLocale(nocntry)) {
 			stdstr(&defaultLocaleName, nocntry);
 		}
-		else {
-			if (!defaultLocaleName) {
-				// make sure we have a default locale name
-				// even though the one asked for doesn't exist
-				stdstr(&defaultLocaleName, "en_US");
-			}
-
-		}
 		delete [] nocntry;
 	}
 	delete [] tmplang;
