@@ -2,7 +2,7 @@
  *  swmgr.cpp   - implementaion of class SWMgr used to interact with an install
  *				base of sword modules.
  *
- * $Id: swmgr.cpp 1808 2005-05-13 01:04:48Z scribe $
+ * $Id: swmgr.cpp 1963 2006-08-30 04:16:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -32,6 +32,7 @@
 
 #include <swmgr.h>
 #include <rawtext.h>
+#include <filemgr.h>
 #include <rawgenbook.h>
 #include <rawcom.h>
 #include <hrefcom.h>
@@ -41,6 +42,8 @@
 #include <gbfplain.h>
 #include <thmlplain.h>
 #include <osisplain.h>
+#include <teiplain.h>
+#include <papyriplain.h>
 #include <gbfstrongs.h>
 #include <gbffootnotes.h>
 #include <gbfheadings.h>
@@ -52,6 +55,7 @@
 #include <osismorph.h>
 #include <osislemma.h>
 #include <osisredletterwords.h>
+#include <osismorphsegmentation.h>
 #include <osisscripref.h>
 #include <thmlstrongs.h>
 #include <thmlfootnotes.h>
@@ -71,6 +75,8 @@
 #include <utf8hebrewpoints.h>
 #include <greeklexattribs.h>
 #include <swfiltermgr.h>
+#include <swcipher.h>
+#include <swoptfilter.h>
 
 #include <swlog.h>
 
@@ -109,7 +115,7 @@ const char *SWMgr::globalConfPath = "/etc/sword.conf:/usr/local/etc/sword.conf";
 #endif  
 
 void SWMgr::init() {
-	SWFilter *tmpFilter = 0;
+	SWOptionFilter *tmpFilter = 0;
 	configPath  = 0;
 	prefixPath  = 0;
 	configType  = 0;
@@ -122,101 +128,109 @@ void SWMgr::init() {
 	optionFilters.clear();
 	cleanupFilters.clear();
 	tmpFilter = new ThMLVariants();
-	optionFilters.insert(FilterMap::value_type("ThMLVariants", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("ThMLVariants", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new GBFStrongs();
-	optionFilters.insert(FilterMap::value_type("GBFStrongs", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("GBFStrongs", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new GBFFootnotes();
-	optionFilters.insert(FilterMap::value_type("GBFFootnotes", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("GBFFootnotes", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new GBFRedLetterWords();
-	optionFilters.insert(FilterMap::value_type("GBFRedLetterWords", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("GBFRedLetterWords", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new GBFMorph();
-	optionFilters.insert(FilterMap::value_type("GBFMorph", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("GBFMorph", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new GBFHeadings();
-	optionFilters.insert(FilterMap::value_type("GBFHeadings", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("GBFHeadings", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new OSISHeadings();
-	optionFilters.insert(FilterMap::value_type("OSISHeadings", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("OSISHeadings", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new OSISStrongs();
-	optionFilters.insert(FilterMap::value_type("OSISStrongs", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("OSISStrongs", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new OSISMorph();
-	optionFilters.insert(FilterMap::value_type("OSISMorph", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("OSISMorph", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new OSISLemma();
-	optionFilters.insert(FilterMap::value_type("OSISLemma", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("OSISLemma", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new OSISFootnotes();
-	optionFilters.insert(FilterMap::value_type("OSISFootnotes", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("OSISFootnotes", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new OSISScripref();
-	optionFilters.insert(FilterMap::value_type("OSISScripref", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("OSISScripref", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new OSISRedLetterWords();
-	optionFilters.insert(FilterMap::value_type("OSISRedLetterWords", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("OSISRedLetterWords", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new OSISMorphSegmentation();
+	optionFilters.insert(OptionFilterMap::value_type("OSISMorphSegmentation", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new ThMLStrongs();
-	optionFilters.insert(FilterMap::value_type("ThMLStrongs", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("ThMLStrongs", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new ThMLFootnotes();
-	optionFilters.insert(FilterMap::value_type("ThMLFootnotes", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("ThMLFootnotes", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new ThMLMorph();
-	optionFilters.insert(FilterMap::value_type("ThMLMorph", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("ThMLMorph", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new ThMLHeadings();
-	optionFilters.insert(FilterMap::value_type("ThMLHeadings", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("ThMLHeadings", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new ThMLLemma();
-	optionFilters.insert(FilterMap::value_type("ThMLLemma", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("ThMLLemma", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new ThMLScripref();
-	optionFilters.insert(FilterMap::value_type("ThMLScripref", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("ThMLScripref", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new UTF8GreekAccents();
-	optionFilters.insert(FilterMap::value_type("UTF8GreekAccents", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("UTF8GreekAccents", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new UTF8HebrewPoints();
-	optionFilters.insert(FilterMap::value_type("UTF8HebrewPoints", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("UTF8HebrewPoints", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new UTF8Cantillation();
-	optionFilters.insert(FilterMap::value_type("UTF8Cantillation", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("UTF8Cantillation", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 	tmpFilter = new GreekLexAttribs();
-	optionFilters.insert(FilterMap::value_type("GreekLexAttribs", tmpFilter));
+	optionFilters.insert(OptionFilterMap::value_type("GreekLexAttribs", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new PapyriPlain();
+	optionFilters.insert(OptionFilterMap::value_type("PapyriPlain", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
 // UTF8Transliterator needs to be handled differently because it should always available as an option, for all modules
 #ifdef _ICU_
 	transliterator = new UTF8Transliterator();
-	optionFilters.insert(FilterMap::value_type("UTF8Transliterator", transliterator));
+	optionFilters.insert(OptionFilterMap::value_type("UTF8Transliterator", transliterator));
 	options.push_back(transliterator->getOptionName());
 	cleanupFilters.push_back(transliterator);
 #endif
@@ -229,11 +243,14 @@ void SWMgr::init() {
 
 	osisplain = new OSISPlain();
 	cleanupFilters.push_back(osisplain);
+
+	teiplain = new TEIPlain();
+	cleanupFilters.push_back(teiplain);
 //#endif
 }
 
 
-void SWMgr::commonInit(SWConfig * iconfig, SWConfig * isysconfig, bool autoload, SWFilterMgr *filterMgr, bool multiMod) {
+void SWMgr::commonInit(SWConfig *iconfig, SWConfig *isysconfig, bool autoload, SWFilterMgr *filterMgr, bool multiMod) {
 
 	init();
 
@@ -317,6 +334,9 @@ SWMgr::~SWMgr() {
 	if (homeConfig)
 		delete homeConfig;
 
+	if (mysysconfig)
+		delete mysysconfig;
+
 	if (myconfig)
 		delete myconfig;
 
@@ -331,106 +351,133 @@ SWMgr::~SWMgr() {
 }
 
 
-void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, std::list<SWBuf> *augPaths) {
+void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, std::list<SWBuf> *augPaths, SWConfig *providedSysConf) {
 	SWBuf path;
+	SWBuf sysConfPath;
 	ConfigEntMap::iterator entry;
 	ConfigEntMap::iterator lastEntry;
 
-	char *envsworddir = getenv ("SWORD_PATH");
-	char *envhomedir  = getenv ("HOME");
+	char *envsworddir = getenv("SWORD_PATH");
+	char *envhomedir  = getenv("HOME");
+	SWConfig *sysConf = 0;
 
 	*configType = 0;
 	//debug=1;
 
-	// check working directory
-	DEBUGSTR("Checking working directory for mods.conf...");
-
-	if (FileMgr::existsFile(".", "mods.conf")) {
-		DEBUGSTR("found\n");
-		stdstr(prefixPath, "./");
-		stdstr(configPath, "./mods.conf");
-		return;
+	// check for a sysConf passed in to us
+	DEBUGSTR("Checking for provided SWConfig(\"sword.conf\")...");
+	if (providedSysConf) {
+		sysConf = providedSysConf;
+		DEBUGSTR("found.\n");
 	}
-
-	DEBUGSTR("\nChecking working directory for mods.d...");
-	if (FileMgr::existsDir(".", "mods.d")) {
-		DEBUGSTR("found\n");
-		stdstr(prefixPath, "./");
-		stdstr(configPath, "./mods.d");
-		*configType = 1;
-		return;
-	}
-
-
-	// check environment variable SWORD_PATH
-	DEBUGSTR("\nChecking SWORD_PATH...");
-
-	if (envsworddir != NULL) {
-		
-		DEBUGSTR("found (" << envsworddir << ")\n");
-		path = envsworddir;
-		if ((envsworddir[strlen(envsworddir)-1] != '\\') && (envsworddir[strlen(envsworddir)-1] != '/'))
-			path += "/";
-
-		DEBUGSTR("\nChecking $SWORD_PATH for mods.conf...");
-		if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
-			DEBUGSTR("found\n");
-			stdstr(prefixPath, path.c_str());
-			path += "mods.conf";
-			stdstr(configPath, path.c_str());
-			return;
+	else {
+		// check working directory
+		DEBUGSTR("\nChecking working directory for sword.conf...");
+		if (FileMgr::existsFile(".", "sword.conf")) {
+			DEBUGSTR("\nOverriding any systemwide or ~/.sword/ sword.conf with one found in current directory.\n");
+			sysConfPath = "./sword.conf";
 		}
+		else {
+			DEBUGSTR("\nChecking working directory for mods.conf...");
+			if (FileMgr::existsFile(".", "mods.conf")) {
+				DEBUGSTR("found\n");
+				stdstr(prefixPath, "./");
+				stdstr(configPath, "./mods.conf");
+				return;
+			}
 
-		DEBUGSTR("\nChecking $SWORD_PATH for mods.d...");
-		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
-			DEBUGSTR("found\n");
-			stdstr(prefixPath, path.c_str());
-			path += "mods.d";
-			stdstr(configPath, path.c_str());
-			*configType = 1;
-			return;
+			DEBUGSTR("\nChecking working directory for mods.d...");
+			if (FileMgr::existsDir(".", "mods.d")) {
+				DEBUGSTR("found\n");
+				stdstr(prefixPath, "./");
+				stdstr(configPath, "./mods.d");
+				*configType = 1;
+				return;
+			}
+
+		   // check working directory ../library/
+			DEBUGSTR("\nChecking working directory ../library/ for mods.d...");
+			if (FileMgr::existsDir("../library", "mods.d")) {
+				DEBUGSTR("found\n");
+				stdstr(prefixPath, "../library/");
+				stdstr(configPath, "../library/mods.d");
+				*configType = 1;
+				return;
+			}
+
+			// check environment variable SWORD_PATH
+			DEBUGSTR("\nChecking SWORD_PATH...");
+
+			if (envsworddir != NULL) {
+				
+				DEBUGSTR("found (" << envsworddir << ")\n");
+				path = envsworddir;
+				if ((envsworddir[strlen(envsworddir)-1] != '\\') && (envsworddir[strlen(envsworddir)-1] != '/'))
+					path += "/";
+
+				DEBUGSTR("\nChecking $SWORD_PATH for mods.conf...");
+				if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
+					DEBUGSTR("found\n");
+					stdstr(prefixPath, path.c_str());
+					path += "mods.conf";
+					stdstr(configPath, path.c_str());
+					return;
+				}
+
+				DEBUGSTR("\nChecking $SWORD_PATH for mods.d...");
+				if (FileMgr::existsDir(path.c_str(), "mods.d")) {
+					DEBUGSTR("found\n");
+					stdstr(prefixPath, path.c_str());
+					path += "mods.d";
+					stdstr(configPath, path.c_str());
+					*configType = 1;
+					return;
+				}
+			}
+
+
+			// check for systemwide globalConfPath
+
+			DEBUGSTR("\nParsing " << globalConfPath << "...");
+			char *globPaths = 0;
+			char *gfp;
+			stdstr(&globPaths, globalConfPath);
+			for (gfp = strtok(globPaths, ":"); gfp; gfp = strtok(0, ":")) {
+				DEBUGSTR("\nChecking for " << gfp << "...");
+				if (FileMgr::existsFile(gfp)) {
+					DEBUGSTR("found\n");
+					break;
+				}
+			}
+			if (gfp)
+				sysConfPath = gfp;
+			delete [] globPaths;
+
+			SWBuf homeDir = envhomedir;
+			if (homeDir.size() > 0) {
+				if ((homeDir[homeDir.size()-1] != '\\') && (homeDir[homeDir.size()-1] != '/'))
+					homeDir += "/";
+				homeDir += ".sword/sword.conf";
+				if (FileMgr::existsFile(homeDir)) {
+					DEBUGSTR("\nOverriding any systemwide sword.conf with one found in users home directory.\n");
+					sysConfPath = homeDir;
+				}
+			}
 		}
 	}
 
-
-	// check for systemwide globalConfPath
-
-	DEBUGSTR("\nParsing " << globalConfPath << "...");
-	char *globPaths = 0;
-	char *gfp;
-	stdstr(&globPaths, globalConfPath);
-	for (gfp = strtok(globPaths, ":"); gfp; gfp = strtok(0, ":")) {
-
-	DEBUGSTR("\nChecking for " << gfp << "...");
-		if (FileMgr::existsFile(gfp))
-			break;
-	}
-	SWBuf sysConfPath;
-	if (gfp)
-		sysConfPath = gfp;
-
-	SWBuf homeDir  = getenv ("HOME");
-	if (homeDir.size() > 0) {
-		if ((homeDir[homeDir.size()-1] != '\\') && (homeDir[homeDir.size()-1] != '/'))
-			homeDir += "/";
-		homeDir += ".sword/sword.conf";
-		if (FileMgr::existsFile(homeDir)) {
-			DEBUGSTR("\nOverriding any systemwide sword.conf with one found in users home directory." << gfp << "...");
-			sysConfPath = homeDir;
-		}
-	}
-
-
 	if (sysConfPath.size()) {
-		DEBUGSTR("found\n");
-		SWConfig etcconf(sysConfPath);
-		if ((entry = etcconf.Sections["Install"].find("DataPath")) != etcconf.Sections["Install"].end()) {
+		sysConf = new SWConfig(sysConfPath);
+	}
+
+	if (sysConf) {
+		if ((entry = sysConf->Sections["Install"].find("DataPath")) != sysConf->Sections["Install"].end()) {
 			path = (*entry).second;
 			if (((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '\\') && ((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '/'))
 				path += "/";
 
 			DEBUGSTR("DataPath in " << sysConfPath << " is set to: " << path);
-			DEBUGSTR("\nChecking for mods.conf in DataPath ");
+			DEBUGSTR("\nChecking for mods.conf in DataPath...");
 			
 			if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 				DEBUGSTR("found\n");
@@ -440,7 +487,7 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 				*configType = 1;
 			}
 
-			DEBUGSTR("\nChecking for mods.d in DataPath ");
+			DEBUGSTR("\nChecking for mods.d in DataPath...");
 
 			if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 				DEBUGSTR("found\n");
@@ -452,8 +499,8 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 		}
 		if (augPaths) {
 			augPaths->clear();
-			entry     = etcconf.Sections["Install"].lower_bound("AugmentPath");
-			lastEntry = etcconf.Sections["Install"].upper_bound("AugmentPath");
+			entry     = sysConf->Sections["Install"].lower_bound("AugmentPath");
+			lastEntry = sysConf->Sections["Install"].upper_bound("AugmentPath");
 			for (;entry != lastEntry; entry++) {
 				path = entry->second;
 				if ((entry->second.c_str()[strlen(entry->second.c_str())-1] != '\\') && (entry->second.c_str()[strlen(entry->second.c_str())-1] != '/'))
@@ -463,19 +510,23 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 		}
 	}
 
-	delete [] globPaths;
+	if ((sysConf) && (!providedSysConf)) {
+		delete sysConf;
+	}
+
 	if (*configType)
 		return;
 
 	// check ~/.sword/
 
-	DEBUGSTR("\nChecking home directory for ~/.sword/mods.conf" << path);
+	DEBUGSTR("\nChecking home directory for ~/.sword...");
 
 	if (envhomedir != NULL) {
 		path = envhomedir;
 		if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
 			path += "/";
 		path += ".sword/";
+		DEBUGSTR("\n  Checking for " << path << "mods.conf...");
 		if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 			DEBUGSTR("found\n");
 			stdstr(prefixPath, path.c_str());
@@ -484,8 +535,7 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 			return;
 		}
 
-		DEBUGSTR("\nChecking home directory for ~/.sword/mods.d" << path);
-
+		DEBUGSTR("\n  Checking for " << path << "mods.d...");
 		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 			DEBUGSTR("found\n");
 			stdstr(prefixPath, path.c_str());
@@ -601,8 +651,11 @@ signed char SWMgr::Load() {
 	signed char ret = 0;
 
 	if (!config) {	// If we weren't passed a config object at construction, find a config file
-		if (!configPath)	// If we weren't passed a config path at construction...
-			findConfig(&configType, &prefixPath, &configPath, &augPaths);
+		if (!configPath) {	// If we weren't passed a config path at construction...
+			DEBUGSTR("LOOKING UP MODULE CONFIGURATION...\n");
+			findConfig(&configType, &prefixPath, &configPath, &augPaths, sysconfig);
+			DEBUGSTR("LOOKING UP MODULE CONFIGURATION COMPLETE.\n\n");
+		}
 		if (configPath) {
 			if (configType)
 				loadConfigDir(configPath);
@@ -634,7 +687,7 @@ signed char SWMgr::Load() {
 		}
 		if (augmentHome) {
 			// augment config with ~/.sword/mods.d if it exists ---------------------
-			char *envhomedir  = getenv ("HOME");
+			char *envhomedir = getenv("HOME");
 			if (envhomedir != NULL && configType != 2) { // 2 = user only
 				SWBuf path = envhomedir;
 				if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
@@ -692,6 +745,8 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 		markup = FMT_THML;
 	else if (!stricmp(sourceformat.c_str(), "OSIS"))
 		markup = FMT_OSIS;
+	else if (!stricmp(sourceformat.c_str(), "TEI"))
+		markup = FMT_TEI;
 	else
 		markup = FMT_GBF;
 
@@ -802,7 +857,8 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 	}
 
 	if (!stricmp(driver, "RawGenBook")) {
-		newmod = new RawGenBook(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str());
+		misc1 = ((entry = section.find("KeyType")) != section.end()) ? (*entry).second : (SWBuf)"TreeKey";
+		newmod = new RawGenBook(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str(), misc1.c_str());
 		pos = 1;
 	}
 
@@ -830,7 +886,7 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 
 void SWMgr::AddGlobalOptions(SWModule *module, ConfigEntMap &section, ConfigEntMap::iterator start, ConfigEntMap::iterator end) {
 	for (;start != end; start++) {
-		FilterMap::iterator it;
+		OptionFilterMap::iterator it;
 		it = optionFilters.find((*start).second);
 		if (it != optionFilters.end()) {
 			module->AddOptionFilter((*it).second);	// add filter to module and option as a valid option
@@ -851,10 +907,23 @@ void SWMgr::AddGlobalOptions(SWModule *module, ConfigEntMap &section, ConfigEntM
 }
 
 
+char SWMgr::filterText(const char *filterName, SWBuf &text, const SWKey *key, const SWModule *module)
+ {
+	char retVal = -1;
+	for (OptionFilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
+		if ((*it).second->getOptionName()) {
+			if (!stricmp(filterName, (*it).second->getOptionName()))
+				retVal = it->second->processText(text, key, module);	// add filter to module
+		}
+	}
+	return retVal;
+}
+
+
 void SWMgr::AddLocalOptions(SWModule *module, ConfigEntMap &section, ConfigEntMap::iterator start, ConfigEntMap::iterator end)
 {
 	for (;start != end; start++) {
-		FilterMap::iterator it;
+		OptionFilterMap::iterator it;
 		it = optionFilters.find((*start).second);
 		if (it != optionFilters.end()) {
 			module->AddOptionFilter((*it).second);	// add filter to module
@@ -866,6 +935,19 @@ void SWMgr::AddLocalOptions(SWModule *module, ConfigEntMap &section, ConfigEntMa
 }
 
 
+// manually specified StripFilters for special cases, like Papyri marks and such
+void SWMgr::AddStripFilters(SWModule *module, ConfigEntMap &section, ConfigEntMap::iterator start, ConfigEntMap::iterator end)
+{
+	for (;start != end; start++) {
+		OptionFilterMap::iterator it;
+		it = optionFilters.find((*start).second);
+		if (it != optionFilters.end()) {
+			module->AddStripFilter((*it).second);	// add filter to module
+		}
+	}
+}
+
+
 void SWMgr::AddRawFilters(SWModule *module, ConfigEntMap &section) {
 	SWBuf sourceformat, cipherKey;
 	ConfigEntMap::iterator entry;
@@ -938,6 +1020,9 @@ void SWMgr::AddStripFilters(SWModule *module, ConfigEntMap &section)
 	else if (!stricmp(sourceformat.c_str(), "OSIS")) {
 		module->AddStripFilter(osisplain);
 	}
+	else if (!stricmp(sourceformat.c_str(), "TEI")) {
+		module->AddStripFilter(teiplain);
+	}
 
 	if (filterMgr)
 		filterMgr->AddStripFilters(module, section);
@@ -960,16 +1045,31 @@ void SWMgr::CreateMods(bool multiMod) {
 		if (driver.length()) {
 			newmod = CreateMod((*it).first, driver, section);
 			if (newmod) {
+				// Filters to add for this module and globally announce as an option to the user
+				// e.g. translit, strongs, redletterwords, etc, so users can turn these on and off globally
 				start = (*it).second.lower_bound("GlobalOptionFilter");
 				end   = (*it).second.upper_bound("GlobalOptionFilter");
 				AddGlobalOptions(newmod, section, start, end);
 
+				// Only add the option to the module, don't announce it's availability
+				// These are useful for like: filters that parse special entryAttribs in a text
+				// or whatever you might want to happen on entry lookup
 				start = (*it).second.lower_bound("LocalOptionFilter");
 				end   = (*it).second.upper_bound("LocalOptionFilter");
 				AddLocalOptions(newmod, section, start, end);
 
-				AddRawFilters(newmod, section);
+				//STRIP FILTERS
+
+				// add all basic ones for for the modtype
 				AddStripFilters(newmod, section);
+
+				// Any special processing for this module when searching:
+				// e.g. for papyri, removed all [](). notation
+				start = (*it).second.lower_bound("LocalStripFilter");
+				end   = (*it).second.upper_bound("LocalStripFilter");
+				AddStripFilters(newmod, section, start, end);
+
+				AddRawFilters(newmod, section);
 				AddRenderFilters(newmod, section);
 				AddEncodingFilters(newmod, section);
 				
@@ -1078,7 +1178,7 @@ char SWMgr::AddModToConfig(FileDesc *conffd, const char *fname)
 
 void SWMgr::setGlobalOption(const char *option, const char *value)
 {
-	for (FilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
+	for (OptionFilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
 		if ((*it).second->getOptionName()) {
 			if (!stricmp(option, (*it).second->getOptionName()))
 				(*it).second->setOptionValue(value);
@@ -1089,7 +1189,7 @@ void SWMgr::setGlobalOption(const char *option, const char *value)
 
 const char *SWMgr::getGlobalOption(const char *option)
 {
-	for (FilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
+	for (OptionFilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
 		if ((*it).second->getOptionName()) {
 			if (!stricmp(option, (*it).second->getOptionName()))
 				return (*it).second->getOptionValue();
@@ -1101,7 +1201,7 @@ const char *SWMgr::getGlobalOption(const char *option)
 
 const char *SWMgr::getGlobalOptionTip(const char *option)
 {
-	for (FilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
+	for (OptionFilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
 		if ((*it).second->getOptionName()) {
 			if (!stricmp(option, (*it).second->getOptionName()))
 				return (*it).second->getOptionTip();
@@ -1120,7 +1220,7 @@ StringList SWMgr::getGlobalOptions()
 StringList SWMgr::getGlobalOptionValues(const char *option)
 {
 	StringList options;
-	for (FilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
+	for (OptionFilterMap::iterator it = optionFilters.begin(); it != optionFilters.end(); it++) {
 		if ((*it).second->getOptionName()) {
 			if (!stricmp(option, (*it).second->getOptionName())) {
 				options = (*it).second->getOptionValues();
