@@ -8,8 +8,10 @@
 #include <stdio.h>
 #include <fcntl.h>
 
+#include <filemgr.h>
 #include <rawverse.h>
 #include <rawcom.h>
+#include <versekey.h>
 
 SWORD_NAMESPACE_START
 
@@ -36,6 +38,9 @@ RawCom::~RawCom()
 }
 
 
+bool RawCom::isWritable() {
+	return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & FileMgr::RDWR) == FileMgr::RDWR));
+}
 /******************************************************************************
  * RawCom::getRawEntry()	- Returns the correct verse when char * cast
  *					is requested
@@ -145,33 +150,4 @@ void RawCom::deleteEntry() {
 }
 
 
-VerseKey &RawCom::getVerseKey() {
-	static VerseKey tmpVK;
-	VerseKey *key;
-	// see if we have a VerseKey * or decendant
-	SWTRY {
-		key = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	SWCATCH ( ... ) {	}
-	if (!key) {
-		ListKey *lkTest = 0;
-		SWTRY {
-			lkTest = SWDYNAMIC_CAST(ListKey, this->key);
-		}
-		SWCATCH ( ... ) {	}
-		if (lkTest) {
-			SWTRY {
-				key = SWDYNAMIC_CAST(VerseKey, lkTest->GetElement());
-			}
-			SWCATCH ( ... ) {	}
-		}
-	}
-	if (!key) {
-		tmpVK = *(this->key);
-		return tmpVK;
-	}
-	else	return *key;
-}
-
-
 SWORD_NAMESPACE_END
