@@ -12,6 +12,7 @@
 #include <rawverse.h>
 #include <rawfiles.h>
 #include <filemgr.h>
+#include <versekey.h>
 
 SWORD_NAMESPACE_START
 
@@ -37,6 +38,14 @@ RawFiles::~RawFiles()
 }
 
 
+/** Is the module writable? :)
+* @return yes or no
+*/
+bool RawFiles::isWritable() {
+	return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & FileMgr::RDWR) == FileMgr::RDWR));
+}
+
+
 /******************************************************************************
  * RawFiles::getRawEntry	- Returns the correct verse when char * cast
  *					is requested
