@@ -9,7 +9,9 @@
 #include <fcntl.h>
 
 #include <zverse.h>
+#include <versekey.h>
 #include <zcom.h>
+#include <filemgr.h>
 
 SWORD_NAMESPACE_START
 
@@ -41,6 +43,12 @@ zCom::~zCom() {
 		delete lastWriteKey;
 }
 
+
+bool zCom::isWritable() {
+	return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & FileMgr::RDWR) == FileMgr::RDWR));
+}
+
+
 /******************************************************************************
  * zCom::getRawEntry	- Returns the correct verse when char * cast
  *					is requested
@@ -177,33 +185,4 @@ void zCom::increment(int steps) {
 }
 
 
-VerseKey &zCom::getVerseKey() {
-	static VerseKey tmpVK;
-	VerseKey *key;
-	// see if we have a VerseKey * or decendant
-	SWTRY {
-		key = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	SWCATCH ( ... ) {	}
-	if (!key) {
-		ListKey *lkTest = 0;
-		SWTRY {
-			lkTest = SWDYNAMIC_CAST(ListKey, this->key);
-		}
-		SWCATCH ( ... ) {	}
-		if (lkTest) {
-			SWTRY {
-				key = SWDYNAMIC_CAST(VerseKey, lkTest->GetElement());
-			}
-			SWCATCH ( ... ) {	}
-		}
-	}
-	if (!key) {
-		tmpVK = *(this->key);
-		return tmpVK;
-	}
-	else	return *key;
-}
-
-
 SWORD_NAMESPACE_END
