@@ -7,10 +7,6 @@
 
 #include <stdlib.h>
 #include <gbfheadings.h>
-#ifndef __GNUC__
-#else
-#include <unixstr.h>
-#endif
 
 SWORD_NAMESPACE_START
 
@@ -18,7 +14,7 @@ SWORD_NAMESPACE_START
 const char oName[] = "Headings";
 const char oTip[] = "Toggles Headings On and Off if they exist";
 
-const SWBuf choices[3] = {"On", "Off", ""};
+const SWBuf choices[3] = {"Off", "On", ""};
 const StringList oValues(&choices[0], &choices[2]);
 
 GBFHeadings::GBFHeadings() : SWOptionFilter(oName, oTip, &oValues) {
