@@ -21,9 +21,16 @@
 #include <utilxml.h>
 #include <versekey.h>
 #include <ctype.h>
+#include <url.h>
 
 SWORD_NAMESPACE_START
 
+GBFHTMLHREF::MyUserData::MyUserData(const SWModule *module, const SWKey *key) : BasicFilterUserData(module, key) {
+	if (module) {
+		version = module->Name(); 
+	}	
+}
+
 GBFHTMLHREF::GBFHTMLHREF() {
 	setTokenStart("<");
 	setTokenEnd(">");
@@ -72,7 +79,7 @@ bool GBFHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData
 
 	if (!substituteToken(buf, token)) {
 		XMLTag tag(token);
-		if (!strncmp(token, "w", 1)) {
+		/*if (!strncmp(token, "w", 1)) {
 			// OSIS Word (temporary until OSISRTF is done)
 			valto = val;
 			num = strstr(token, "lemma=\"x-Strongs:");
@@ -91,13 +98,37 @@ bool GBFHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData
 					//cout << buf;
 					
 				}
-				/*	forget these for now
-				else {
+				//	forget these for now
+				//else {
 					// verb morph
-					sprintf(wordstr, "%03d", word-1);
-					module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
+					//sprintf(wordstr, "%03d", word-1);
+					//module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
+				//}
+			}
+			else {
+				num = strstr(token, "lemma=\"strong:");
+				if (num) {
+					for (num+=14; ((*num) && (*num != '\"')); num++)
+						*valto++ = *num;
+					*valto = 0;
+					if (atoi((!isdigit(*val))?val+1:val) < 5627) {
+						buf += " <small><em>&lt;<a href=\"type=Strongs value=";
+						for (tok = val; *tok; tok++)
+								buf += *tok;
+						buf += "\">";
+						for (tok = (!isdigit(*val))?val+1:val; *tok; tok++)
+								buf += *tok;
+						buf += "</a>&gt;</em></small> ";
+						//cout << buf;
+						
+					}
+					//	forget these for now
+					//else {
+						// verb morph
+						//sprintf(wordstr, "%03d", word-1);
+						//module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
+					//}
 				}
-				*/
 			}
 			valto = val;
 			num = strstr(token, "morph=\"x-Robinson:");
@@ -115,11 +146,13 @@ bool GBFHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData
 						buf += *tok;		
 				buf += "</a>)</em></small> ";					
 			}
-		}
+		}*/
 		
-		else if (!strncmp(token, "WG", 2) || !strncmp(token, "WH", 2)) { // strong's numbers
-			buf += " <small><em>&lt;<a href=\"type=Strongs value=";
-			for (tok = token+1; *tok; tok++)
+		// else 
+		if (!strncmp(token, "WG", 2)) { // strong's numbers
+			//buf += " <small><em>&lt;<a href=\"type=Strongs value=";
+			buf += " <small><em>&lt;<a href=\"passagestudy.jsp?action=showStrongs&type=Greek&value=";
+			for (tok = token+2; *tok; tok++)
 				//if(token[i] != '\"')
 					buf += *tok;
 			buf += "\">";
@@ -128,10 +161,34 @@ bool GBFHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData
 					buf += *tok;
 			buf += "</a>&gt;</em></small>";
 		}
-
-		else if (!strncmp(token, "WTG", 3) || !strncmp(token, "WTH", 3)) { // strong's numbers tense
-			buf += " <small><em>(<a href=\"type=Strongs value=";
+		else if (!strncmp(token, "WH", 2)) { // strong's numbers
+			//buf += " <small><em>&lt;<a href=\"type=Strongs value=";
+			buf += " <small><em>&lt;<a href=\"passagestudy.jsp?action=showStrongs&type=Hebrew&value=";
+			for (tok = token+2; *tok; tok++)
+				//if(token[i] != '\"')
+					buf += *tok;
+			buf += "\">";
 			for (tok = token + 2; *tok; tok++)
+				//if(token[i] != '\"')
+					buf += *tok;
+			buf += "</a>&gt;</em></small>";
+		}
+		else if (!strncmp(token, "WTG", 3)) { // strong's numbers tense
+			//buf += " <small><em>(<a href=\"type=Strongs value=";
+			buf += " <small><em>(<a href=\"passagestudy.jsp?action=showStrongs&type=Greek&value=";
+			for (tok = token + 3; *tok; tok++)
+				if(*tok != '\"')
+					buf += *tok;
+			buf += "\">";
+			for (tok = token + 3; *tok; tok++)
+				if(*tok != '\"')
+					buf += *tok;
+			buf += "</a>)</em></small>";
+		}
+		else if (!strncmp(token, "WTH", 3)) { // strong's numbers tense
+			//buf += " <small><em>(<a href=\"type=Strongs value=";
+			buf += " <small><em>(<a href=\"passagestudy.jsp?action=showStrongs&type=Hebrew&value=";
+			for (tok = token + 3; *tok; tok++)
 				if(*tok != '\"')
 					buf += *tok;
 			buf += "\">";
@@ -142,7 +199,9 @@ bool GBFHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData
 		}
 
 		else if (!strncmp(token, "WT", 2) && strncmp(token, "WTH", 3) && strncmp(token, "WTG", 3)) { // morph tags
-			buf += " <small><em>(<a href=\"type=morph class=none value=";
+			//buf += " <small><em>(<a href=\"type=morph class=none value=";
+			buf += " <small><em>(<a href=\"passagestudy.jsp?action=showMorph&type=Greek&value=";
+			
 			for (tok = token + 2; *tok; tok++)
 				if(*tok != '\"')
 					buf += *tok;
@@ -170,14 +229,17 @@ bool GBFHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData
 			SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 			VerseKey *vkey;
 			// see if we have a VerseKey * or descendant
-			try {
+			SWTRY {
 				vkey = SWDYNAMIC_CAST(VerseKey, u->key);
 			}
-			catch ( ... ) {	}
+			SWCATCH ( ... ) {	}
 			if (vkey) {
 				// leave this special osis type in for crossReference notes types?  Might thml use this some day? Doesn't hurt.
 				//char ch = ((tag.getAttribute("type") && ((!strcmp(tag.getAttribute("type"), "crossReference")) || (!strcmp(tag.getAttribute("type"), "x-cross-ref")))) ? 'x':'n');
-				buf.appendFormatted("<a href=\"noteID=%s.%c.%s\"><small><sup>*%c</sup></small></a> ", vkey->getText(), 'n', footnoteNumber.c_str(), 'n');
+				buf.appendFormatted("<a href=\"passagestudy.jsp?action=showNote&type=n&value=%s&module=%s&passage=%s\"><small><sup>*n</sup></small></a> ", 
+					URL::encode(footnoteNumber.c_str()).c_str(),
+					URL::encode(u->version.c_str()).c_str(), 
+					URL::encode(vkey->getText()).c_str());
 			}
 			u->suspendTextPassThru = true;
 		}
