@@ -21,7 +21,7 @@ char Latin1UTF8::processText(SWBuf &text, const SWKey *key, const SWModule *modu
     const unsigned char *from;
 
 	 if ((unsigned long)key < 2)	// hack, we're en(1)/de(0)ciphering
-		return -1;
+		return (char)-1;
 
 	SWBuf orig = text;
 	from = (const unsigned char *)orig.c_str();
