@@ -30,10 +30,21 @@ SWORD_NAMESPACE_START
 OSISWEBIF::OSISWEBIF() : baseURL(""), passageStudyURL(baseURL + "passagestudy.jsp"), javascript(false) {
 }
 
+
+BasicFilterUserData *OSISWEBIF::createUserData(const SWModule *module, const SWKey *key) {
+	MyUserData *u = new MyUserData(module, key);
+	u->wordsOfChristStart = "<span class=\"wordsOfJesus\"> ";
+	u->wordsOfChristEnd   = "</span> ";
+	return u;
+}
+
+
 bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData) {
+	MyUserData *u = (MyUserData *)userData;
+	SWBuf scratch;
+	bool sub = (u->suspendTextPassThru) ? substituteToken(scratch, token) : substituteToken(buf, token);
+	if (!sub) {
   // manually process if it wasn't a simple substitution
-	if (!substituteToken(buf, token)) {
-		MyUserData *u = (MyUserData *)userData;
 		XMLTag tag(token);
 
 		// <w> tag
@@ -61,7 +72,7 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 				if (attrib = tag.getAttribute("xlit")) {
 					val = strchr(attrib, ':');
 					val = (val) ? (val + 1) : attrib;
-					buf.appendFormatted(" %s", val);
+//					buf.appendFormatted(" %s", val);
 				}
 				if (attrib = tag.getAttribute("gloss")) {
 					val = strchr(attrib, ':');
@@ -69,10 +80,10 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 					buf.appendFormatted(" %s", val);
 				}
 				if (attrib = tag.getAttribute("lemma")) {
-					int count = tag.getAttributePartCount("lemma");
+					int count = tag.getAttributePartCount("lemma", ' ');
 					int i = (count > 1) ? 0 : -1;		// -1 for whole value cuz it's faster, but does the same thing as 0
 					do {
-						attrib = tag.getAttribute("lemma", i);
+						attrib = tag.getAttribute("lemma", i, ' ');
 						if (i < 0) i = 0;	// to handle our -1 condition
 						val = strchr(attrib, ':');
 						val = (val) ? (val + 1) : attrib;
@@ -89,10 +100,10 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 					if ((strstr(savelemma.c_str(), "3588")) && (lastText.length() < 1))
 						show = false;
 					if (show) {
-						int count = tag.getAttributePartCount("morph");
+						int count = tag.getAttributePartCount("morph", ' ');
 						int i = (count > 1) ? 0 : -1;		// -1 for whole value cuz it's faster, but does the same thing as 0
 						do {
-							attrib = tag.getAttribute("morph", i);
+							attrib = tag.getAttribute("morph", i, ' ');
 							if (i < 0) i = 0;	// to handle our -1 condition
 							val = strchr(attrib, ':');
 							val = (val) ? (val + 1) : attrib;
@@ -117,11 +128,16 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 		// <note> tag
 		else if (!strcmp(tag.getName(), "note")) {
 			if (!tag.isEndTag()) {
+                                SWBuf type = tag.getAttribute("type");
+                                bool strongsMarkup = (type == "x-strongsMarkup" || type == "strongsMarkup");    // the latter is deprecated
+                                if (strongsMarkup) {
+                                        tag.setEmpty(false);    // handle bug in KJV2003 module where some note open tags were <note ... />
+                                }                       
+                                                        
 				if (!tag.isEmpty()) {
-					SWBuf type = tag.getAttribute("type");
-
-					if (type != "strongsMarkup") {	// leave strong's markup notes out, in the future we'll probably have different option filters to turn different note types on or off
+					if (!strongsMarkup) {	// leave strong's markup notes out, in the future we'll probably have different option filters to turn different note types on or off
 						SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
+						SWBuf modName = (u->module) ? u->module->Name() : "";
 						VerseKey *vkey;
 						// see if we have a VerseKey * or descendant
 						SWTRY {
@@ -131,13 +147,15 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 						if (vkey) {
 							char ch = ((tag.getAttribute("type") && ((!strcmp(tag.getAttribute("type"), "crossReference")) || (!strcmp(tag.getAttribute("type"), "x-cross-ref")))) ? 'x':'n');
 //							buf.appendFormatted("<a href=\"noteID=%s.%c.%s\"><small><sup>*%c</sup></small></a> ", vkey->getText(), ch, footnoteNumber.c_str(), ch);
+							buf.appendFormatted("<span class=\"fn\" onclick=\"f(\'%s\',\'%s\',\'%s\');\" >%c</span>", modName.c_str(), u->key->getText(), footnoteNumber.c_str(), ch);
 						}
 					}
-					u->suspendTextPassThru = true;
+					u->suspendTextPassThru = (++u->suspendLevel);
 				}
 			}
 			if (tag.isEndTag()) {
-				u->suspendTextPassThru = false;
+				u->suspendTextPassThru = (--u->suspendLevel);
+
 			}
 		}
 
@@ -151,95 +169,6 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 			}
 		}
 
-		// <catchWord> & <rdg> tags (italicize)
-		else if (!strcmp(tag.getName(), "rdg") || !strcmp(tag.getName(), "catchWord")) {
-			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				if (!u->suspendTextPassThru)
-					buf += "<i>";
-			}
-			else if (tag.isEndTag()) {
-				if (!u->suspendTextPassThru)
-					buf += "</i>";
-			}
-		}
-
-                // <hi> text highlighting
-		else if (!strcmp(tag.getName(), "hi")) {
-			SWBuf type = tag.getAttribute("type");
-			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				if (type == "b" || type == "x-b") {
-					if (!u->suspendTextPassThru)
-						buf += "<b>";
-					u->inBold = true;
-				}
-				else {	// all other types
-					if (!u->suspendTextPassThru)
-						buf += "<i>";
-				}
-			}
-			else if (tag.isEndTag()) {
-				if(u->inBold) {
-					if (!u->suspendTextPassThru)
-						buf += "</b>";
-					u->inBold = false;
-				}
-				else
-					if (!u->suspendTextPassThru)
-						 buf += "</i>";
-			}
-		}
-
-		// <q> quote
-		else if (!strcmp(tag.getName(), "q")) {
-			SWBuf type = tag.getAttribute("type");
-			SWBuf who = tag.getAttribute("who");
-			const char *lev = tag.getAttribute("level");
-			int level = (lev) ? atoi(lev) : 1;
-			
-			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				/*buf += "{";*/
-
-				//alternate " and '
-				if (u->osisQToTick)
-					buf += (level % 2) ? '\"' : '\'';
-				
-				if (who == "Jesus") {
-					buf += "<span class=\"wordsOfJesus\"> ";
-				}
-			}
-			else if (tag.isEndTag()) {
-				//alternate " and '
-				if (u->osisQToTick)
-					buf += (level % 2) ? '\"' : '\'';
-				buf += "</span>";
-			}
-			else {	// empty quote marker
-				//alternate " and '
-				if (u->osisQToTick)
-					buf += (level % 2) ? '\"' : '\'';
-			}
-		}
-
-		// <transChange>
-		else if (!strcmp(tag.getName(), "transChange")) {
-			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				SWBuf type = tag.getAttribute("type");
-				u->lastTransChange = type;
-
-				// just do all transChange tags this way for now
-				if ((type == "added") || (type == "supplied"))
-					buf += "<i>";
-				else if (type == "tenseChange")
-					buf += "*";
-			}
-			else if (tag.isEndTag()) {
-				SWBuf type = u->lastTransChange;
-				if ((type == "added") || (type == "supplied"))
-					buf += "</i>";
-			}
-			else {	// empty transChange marker?
-			}
-		}
 		// ok to leave these in
 		else if (!strcmp(tag.getName(), "div")) {
 			buf += tag;
@@ -250,6 +179,13 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 		else if (!strcmp(tag.getName(), "br")) {
 			buf += tag;
 		}
+
+		// handled appropriately in base class
+		// <catchWord> & <rdg> tags (italicize)
+		// <hi> text highlighting
+		// <q> quote
+		// <milestone type="cQuote" marker="x"/>
+		// <transChange>
 		else {
 			return OSISHTMLHREF::handleToken(buf, token, userData);
 		}
