@@ -15,9 +15,9 @@
  ***************************************************************************/
 
 #include <stdlib.h>
-#include <string.h>
 #include <thmlhtml.h>
 #include <swmodule.h>
+#include <utilxml.h>
 
 SWORD_NAMESPACE_START
 
@@ -129,82 +129,94 @@ ThMLHTML::ThMLHTML() {
 */
 	setTokenCaseSensitive(true);
 
-	addTokenSubstitute("/scripRef", " </a>");
 	addTokenSubstitute("note", " <font color=\"#800000\"><small>(");
 	addTokenSubstitute("/note", ")</small></font> ");
 }
 
 
-bool ThMLHTML::handleToken(char **buf, const char *token, DualStringMap &userData) {
-	if (!substituteToken(buf, token)) {
-	// manually process if it wasn't a simple substitution
-		if (!strncmp(token, "sync type=\"Strongs\" value=\"", 27)) {
-                        if (token[27] == 'H' || token[27] == 'G' || token[27] == 'A') {
-        			pushString(buf, "<small><em>");
-	        		for (const char *tok = token + 5; *tok; tok++)
-		        		if(*tok != '\"')
-			        		*(*buf)++ = *tok;
-        			pushString(buf, "</em></small>");
-                        }
-                        else if (token[27] == 'T') {
-        			pushString(buf, "<small><i>");
-        			for (unsigned int i = 29; token[i] != '\"'; i++)
-        				*(*buf)++ = token[i];
-        			pushString(buf, "</i></small>");
-                        }
+bool ThMLHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData) {
+	if (!substituteToken(buf, token)) { // manually process if it wasn't a simple substitution
+		MyUserData *u = (MyUserData *)userData;
+		XMLTag tag(token);
+		if (!strcmp(tag.getName(), "sync")) {
+			if (tag.getAttribute("type") && tag.getAttribute("value") && !strcmp(tag.getAttribute("type"), "Strongs")) {
+				const char* value = tag.getAttribute("value");
+				if (*value == 'H' || *value == 'G' || *value == 'A') {
+					value++;
+					buf += "<small><em>";
+					buf += value;
+					buf += "</em></small>";
+				}
+				else if (*value == 'T') {
+					value += 2;
+
+					buf += "<small><i>";
+					buf += value;
+					buf += "</i></small>";
+				}
+			}
+			else if (tag.getAttribute("type") && tag.getAttribute("value") && !strcmp(tag.getAttribute("type"), "morph")) {
+				buf += "<small><em>";
+				buf += tag.getAttribute("value");
+				buf += "</em></small>";
+			}
+			else if (tag.getAttribute("type") && tag.getAttribute("value") && !strcmp(tag.getAttribute("type"), "lemma")) {
+				buf += "<small><em>(";
+				buf += tag.getAttribute("value");
+				buf += ")</em></small>";
+			}
 		}
-		else if (!strncmp(token, "sync type=\"morph\" value=\"", 25)) {
-			pushString(buf, "<small><em>");
-			for (unsigned int i = 25; token[i] != '\"'; i++)
-				*(*buf)++ = token[i];
-			pushString(buf, "</em></small>");
+		else if (!strcmp(tag.getName(), "div")) {
+			if (tag.isEndTag() && (u->SecHead)) {
+				buf += "</i></b><br />";
+				u->SecHead = false;
+			}
+			else if (tag.getAttribute("class")) {
+				if (!strcmp(tag.getAttribute("class"), "sechead")) {
+					u->SecHead = true;
+					buf += "<br /><b><i>";
+				}
+				else if (!strcmp(tag.getAttribute("class"), "title")) {
+					u->SecHead = true;
+					buf += "<br /><b><i>";
+				}
+			}
 		}
-		else if (!strncmp(token, "sync type=\"lemma\" value=\"", 25)) {
-			pushString(buf, "<small><em>(");
-			for (unsigned int i = 25; token[i] != '\"'; i++)
-				*(*buf)++ = token[i];
-			pushString(buf, ")</em></small>");
-		}
-		else if (!strncmp(token, "scripRef", 8)) {
-			pushString(buf, "<a href=\"");
-			for (const char *tok = token + 9; *tok; tok++)
-				if(*tok != '\"')
-					*(*buf)++ = *tok;
-			*(*buf)++ = '\"';
-			*(*buf)++ = '>';
-		}
-		else if (!strncmp(token, "img ", 4)) {
+		else if (!strcmp(tag.getName(), "img")) {
 			const char *src = strstr(token, "src");
 			if (!src)		// assert we have a src attribute
 				return false;
 
-			*(*buf)++ = '<';
+			buf += '<';
 			for (const char *c = token; *c; c++) {
 				if (c == src) {
 					for (;((*c) && (*c != '"')); c++)
-						*(*buf)++ = *c;
+						buf += *c;
 
 					if (!*c) { c--; continue; }
 
-					*(*buf)++ = '"';
+					buf += '"';
 					if (*(c+1) == '/') {
-						pushString(buf, "file:");
-						pushString(buf, module->getConfigEntry("AbsoluteDataPath"));
-						if (*((*buf)-1) == '/')
+						buf += "file:";
+						buf += userData->module->getConfigEntry("AbsoluteDataPath");
+						if (buf[buf.length()-2] == '/')
 							c++;		// skip '/'
 					}
 					continue;
 				}
-				*(*buf)++ = *c;
+				buf += *c;
 			}
-			*(*buf)++ = '>';
+			buf += '>';
 		}
-		else if(!strncmp(token, "note", 4)) {
-                        pushString(buf, " <font color=\"#800000\"><small>(");
-                }
+		else if (!strcmp(tag.getName(), "scripRef")) { //do nothing with scrip refs, we leave them out
 
+		}
 		else {
-			return false;  // we still didn't handle token
+			buf += '<';
+			buf += token;
+			buf += '>';
+
+//			return false;  // we still didn't handle token
 		}
 	}
 	return true;
