@@ -18,15 +18,18 @@
 #include <thmlhtmlhref.h>
 #include <swmodule.h>
 #include <utilxml.h>
+#include <utilstr.h>
 #include <versekey.h>
+#include <url.h>
 
 SWORD_NAMESPACE_START
-
+ 
 
 ThMLHTMLHREF::MyUserData::MyUserData(const SWModule *module, const SWKey *key) : BasicFilterUserData(module, key) {
 	if (module) {
 		version = module->Name();
 		BiblicalText = (!strcmp(module->Type(), "Biblical Texts"));
+		SecHead = false;
 	}	
 }
 
@@ -53,27 +56,22 @@ bool ThMLHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 		if (tag.getName() && !strcmp(tag.getName(), "sync")) {
 			SWBuf value = tag.getAttribute("value");
 			if (tag.getAttribute("type") && !strcmp(tag.getAttribute("type"), "morph")) { //&gt;
-				buf += "<small><em>(<a href=\"";
-				buf += "type=";
-				buf += tag.getAttribute("type");
-	
-				//const char* value = tag.getAttribute("value");
-				buf += " value=";
-				buf += (value.length()) ? value.c_str() : "";
-				buf += "\">";
-				buf += (value.length()) ? value.c_str() : "";
-				buf += "</a>) </em></small>";
+				if(value.length())
+					buf.appendFormatted("<small><em>(<a href=\"passagestudy.jsp?action=showMorph&type=Greek&value=%s\">*s</a>) </em></small>", 
+						URL::encode(value.c_str()).c_str(),
+						value.c_str());
 			}
 			else if (tag.getAttribute("type") && !strcmp(tag.getAttribute("type"), "Strongs")) {
-				buf += "<small><em>&lt;<a href=\"";
-				buf += "type=";
-				buf += tag.getAttribute("type");
-	
-				//const char* value = tag.getAttribute("value");
-				buf += " value=";
-				buf += (value.length()) ? value.c_str() : "";
-				buf += "\">";
-				value<<1;
+				if(*value == 'H') {
+					value<<1;
+					buf.appendFormatted("<small><em>&lt;<a href=\"passagestudy.jsp?action=showStrongs&type=Hebrew&value=%s\">",
+						URL::encode(value.c_str()).c_str());
+				}
+				else if(*value == 'G') {
+					value<<1;
+					buf.appendFormatted("<small><em>&lt;<a href=\"passagestudy.jsp?action=showStrongs&type=Greek&value=%s\">",
+						URL::encode(value.c_str()).c_str());
+				}
 				buf += (value.length()) ? value.c_str() : "";
 				buf += "</a>&gt; </em></small>";
 			}
@@ -92,14 +90,19 @@ bool ThMLHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 					SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 					VerseKey *vkey;
 					// see if we have a VerseKey * or descendant
-					try {
+					SWTRY {
 						vkey = SWDYNAMIC_CAST(VerseKey, u->key);
 					}
-					catch ( ... ) {	}
+					SWCATCH ( ... ) {	}
 					if (vkey) {
 						// leave this special osis type in for crossReference notes types?  Might thml use this some day? Doesn't hurt.
 						char ch = ((tag.getAttribute("type") && ((!strcmp(tag.getAttribute("type"), "crossReference")) || (!strcmp(tag.getAttribute("type"), "x-cross-ref")))) ? 'x':'n');
-						buf.appendFormatted("<a href=\"noteID=%s.%c.%s\"><small><sup>*%c</sup></small></a> ", vkey->getText(), ch, footnoteNumber.c_str(), ch);
+						buf.appendFormatted("<a href=\"passagestudy.jsp?action=showNote&type=%c&value=%s&module=%s&passage=%s\"><small><sup>*%c</sup></small></a> ", 
+							ch, 
+							URL::encode(footnoteNumber.c_str()).c_str(), 
+							URL::encode(u->version.c_str()).c_str(), 
+							URL::encode(vkey->getText()).c_str(), 
+							ch);
 					}
 					u->suspendTextPassThru = true;
 				}
@@ -121,29 +124,29 @@ bool ThMLHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 					if (!refList.length())
 						refList = u->lastTextNode;
 					SWBuf version = tag.getAttribute("version");
-					buf += "&nbsp<a href=\"";
-					if (version.length()) {
-						buf += "version=";
-						buf += version;
-						buf += " ";
-					}
-					buf += "passage=";
-					buf += refList.c_str();
-					buf += "\">";
+					
+					buf.appendFormatted("&nbsp;<a href=\"passagestudy.jsp?action=showRef&type=scripRef&value=%s&module=%s\">",
+						(refList.length()) ? URL::encode(refList.c_str()).c_str() : "", 
+						(version.length()) ? URL::encode(version.c_str()).c_str() : "");
 					buf += u->lastTextNode.c_str();
-					buf += "</a>&nbsp";
+					buf += "</a>&nbsp;";
 				}
 				else {
 					SWBuf footnoteNumber = u->startTag.getAttribute("swordFootnote");
 					VerseKey *vkey;
 					// see if we have a VerseKey * or descendant
-					try {
+					SWTRY {
 						vkey = SWDYNAMIC_CAST(VerseKey, u->key);
 					}
-					catch ( ... ) {}
+					SWCATCH ( ... ) {}
 					if (vkey) {
 						// leave this special osis type in for crossReference notes types?  Might thml use this some day? Doesn't hurt.
-						buf.appendFormatted("<a href=\"noteID=%s.x.%s\"><small><sup>*x</sup></small></a> ", vkey->getText(), footnoteNumber.c_str());
+						//buf.appendFormatted("<a href=\"noteID=%s.x.%s\"><small><sup>*x</sup></small></a> ", vkey->getText(), footnoteNumber.c_str());
+						buf.appendFormatted("<a href=\"passagestudy.jsp?action=showNote&type=x&value=%s&module=%s&passage=%s\"><small><sup>*x</sup></small></a> ",  
+							URL::encode(footnoteNumber.c_str()).c_str(), 
+							URL::encode(u->version.c_str()).c_str(),
+							URL::encode(vkey->getText()).c_str());
+					
 					}
 				}
 
@@ -165,6 +168,12 @@ bool ThMLHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 					u->SecHead = true;
 					buf += "<br /><b><i>";
 				}
+				else {
+					buf += tag;
+				}
+			}
+			else {
+				buf += tag;
 			}
 		}
 		else if (tag.getName() && (!strcmp(tag.getName(), "img") || !strcmp(tag.getName(), "image"))) {
