@@ -7,17 +7,14 @@
 
 #include <stdlib.h>
 #include <thmllemma.h>
-#ifndef __GNUC__
-#else
-#include <unixstr.h>
-#endif
+#include <utilstr.h>
 
 SWORD_NAMESPACE_START
 
 const char oName[] = "Lemmas";
 const char oTip[] = "Toggles Lemmas On and Off if they exist";
 
-const SWBuf choices[3] = {"On", "Off", ""};
+const SWBuf choices[3] = {"Off", "On", ""};
 const StringList oValues(&choices[0], &choices[2]);
 
 ThMLLemma::ThMLLemma() : SWOptionFilter(oName, oTip, &oValues) {
