@@ -69,6 +69,7 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 					if (atoi((!isdigit(*val))?val+1:val) < 5627) {
 						// normal strongs number
 						sprintf(wordstr, "%03d", word);
+						module->getEntryAttributes()["Word"][wordstr]["PartCount"] = "1";
 						module->getEntryAttributes()["Word"][wordstr]["Lemma"] = val;
 						module->getEntryAttributes()["Word"][wordstr]["LemmaClass"] = "strong";
 						tmp = "";
@@ -77,10 +78,13 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 						newText = true;
 					}
 					else {
+/*
 						// verb morph
 						sprintf(wordstr, "%03d", word);
 						module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
 						module->getEntryAttributes()["Word"][wordstr]["MorphClass"] = "OLBMorph";
+*/
+						word--;	// for now, completely ignore this word attribute.
 					}
 					word++;
 				}
