@@ -11,6 +11,7 @@
 #include <utilstr.h>
 
 #include <utf8nfkd.h>
+#include <swbuf.h>
 
 SWORD_NAMESPACE_START
 
@@ -27,18 +28,18 @@ char UTF8NFKD::processText(SWBuf &text, const SWKey *key, const SWModule *module
 	if ((unsigned long)key < 2)	// hack, we're en(1)/de(0)ciphering
 		return -1;
         
-	int32_t len = text.length() * 2;
+	int32_t len =  5 + text.length() * 5;
         source = new UChar[len + 1]; //each char could become a surrogate pair
 
 	// Convert UTF-8 string to UTF-16 (UChars)
-        len = ucnv_toUChars(conv, source, len, text.c_str(), -1, &err);
+        int32_t ulen = ucnv_toUChars(conv, source, len, text.c_str(), -1, &err);
         target = new UChar[len + 1];
 
         //compatability decomposition
-        unorm_normalize(source, len, UNORM_NFKD, 0, target, len, &err);
+        ulen = unorm_normalize(source, ulen, UNORM_NFKD, 0, target, len, &err);
 
-	   text.setSize(text.size()*2);
-	   len = ucnv_fromUChars(conv, text.getRawData(), text.size(), target, -1, &err);
+	   text.setSize(len);
+	   len = ucnv_fromUChars(conv, text.getRawData(), len, target, ulen, &err);
 	   text.setSize(len);
 
 	   delete [] source;
