@@ -11,6 +11,7 @@
 #include <utilstr.h>
 #include <rawstr.h>
 #include <rawld.h>
+#include <filemgr.h>
 
 SWORD_NAMESPACE_START
 
@@ -37,6 +38,11 @@ RawLD::~RawLD()
 }
 
 
+bool RawLD::isWritable() {
+	 return ((idxfd->getFd() > 0) && ((idxfd->mode & FileMgr::RDWR) == FileMgr::RDWR));
+}
+
+
 /******************************************************************************
  * RawLD::strongsPad	- Pads a key if (it-1) is 100% digits to 5 places
  *						allows for final to be alpha, e.g. '123B'
