@@ -8,6 +8,7 @@
 #include <stdio.h>
 #include <fcntl.h>
 
+#include <filemgr.h>
 #include <utilstr.h>
 #include <rawstr4.h>
 #include <rawld4.h>
@@ -37,6 +38,11 @@ RawLD4::~RawLD4()
 }
 
 
+bool RawLD4::isWritable() {
+	return ((idxfd->getFd() > 0) && ((idxfd->mode & FileMgr::RDWR) == FileMgr::RDWR));
+}
+
+
 /******************************************************************************
  * RawLD4::strongsPad	- Pads a key if (it-1) is 100% digits to 5 places
  *						allows for final to be alpha, e.g. '123B'
