@@ -4,6 +4,7 @@
  */
 
 #include <swld.h>
+#include <strkey.h>
 
 SWORD_NAMESPACE_START
 
@@ -35,6 +36,9 @@ SWLD::~SWLD()
 }
 
 
+SWKey *SWLD::CreateKey() { return new StrKey(); }
+
+
 /******************************************************************************
  * SWLD::KeyText - Sets/gets module KeyText, getting from saved text if key is
  *				persistent
