@@ -11,6 +11,7 @@
 #include <utilstr.h>
 #include <zstr.h>
 #include <zld.h>
+#include <filemgr.h>
 
 SWORD_NAMESPACE_START
 
@@ -37,6 +38,11 @@ zLD::~zLD() {
 }
 
 
+bool zLD::isWritable() {
+	return ((idxfd->getFd() > 0) && ((idxfd->mode & FileMgr::RDWR) == FileMgr::RDWR));
+}
+
+
 /******************************************************************************
  * zLD::strongsPad	- Pads a key if it is 100% digits to 5 places
  *
