@@ -4,11 +4,14 @@
  *		  etc.)
  */
 
+#include <sysdata.h>
 #include <swmodule.h>
 #include <utilstr.h>
 #include <regex.h>	// GNU
 #include <swfilter.h>
 #include <versekey.h>	// KLUDGE for Search
+#include <treekeyidx.h>	// KLUDGE for Search
+#include <swoptfilter.h>
 #include <filemgr.h>
 #ifndef _MSC_VER
 #include <iostream>
@@ -16,8 +19,21 @@
 
 #ifdef USELUCENE
 #include <CLucene.h>
-using namespace lucene::search;
+#include <CLucene/CLBackwards.h>
+
+//Lucence includes
+//#include "CLucene.h"
+//#include "CLucene/util/Reader.h"
+//#include "CLucene/util/Misc.h"
+//#include "CLucene/util/dirent.h"
+
+using namespace lucene::index;
+using namespace lucene::analysis;
+using namespace lucene::util;
+using namespace lucene::store;
+using namespace lucene::document;
 using namespace lucene::queryParser;
+using namespace lucene::search;
 #endif
 
 
@@ -25,6 +41,8 @@ SWORD_NAMESPACE_START
 
 SWDisplay SWModule::rawdisp;
 
+typedef std::list<SWBuf> StringList;
+
 /******************************************************************************
  * SWModule Constructor - Initializes data for instance of SWModule
  *
@@ -57,7 +75,7 @@ SWModule::SWModule(const char *imodname, const char *imoddesc, SWDisplay *idisp,
 	stripFilters = new FilterList();
 	rawFilters = new FilterList();
 	renderFilters = new FilterList();
-	optionFilters = new FilterList();
+	optionFilters = new OptionFilterList();
 	encodingFilters = new FilterList();
 	skipConsecutiveLinks = true;
 	procEntAttr = true;
@@ -379,12 +397,12 @@ void SWModule::decrement(int steps) {
  *	justCheckIfSupported	- if set, don't search, only tell if this
  *							function supports requested search.
  *
- * RET: listkey set to verses that contain istr
+ * RET: ListKey set to verses that contain istr
  */
 
 ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *scope, bool *justCheckIfSupported, void (*percent)(char, void *), void *percentUserData) {
 
-	listkey.ClearList();
+	listKey.ClearList();
 
 #ifdef USELUCENE
 	SWBuf target = getConfigEntry("AbsoluteDataPath");
@@ -400,13 +418,13 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 			*justCheckIfSupported = true;
 		}
 #endif
-		return listkey;
+		return listKey;
 	}
 	
-	SWKey *savekey = 0;
-	SWKey *searchkey = 0;
+	SWKey *saveKey = 0;
+	SWKey *searchKey = 0;
+	SWKey *resultKey = CreateKey();
 	regex_t preg;
-	SWKey textkey;
 	char **words = 0;
 	char *wordBuf = 0;
 	int wordCount = 0;
@@ -414,20 +432,22 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 	terminateSearch = false;
 	char perc = 1;
 	bool savePEA = isProcessEntryAttributes();
+   // determine if we might be doing special strip searches.  useful for knowing if we can use shortcuts
+	bool specialStrips = (getConfigEntry("LocalStripFilter") || strchr(istr, '<'));
 
 	processEntryAttributes(searchType == -3);
 	
 
 	if (!key->Persist()) {
-		savekey = CreateKey();
-		*savekey = *key;
+		saveKey = CreateKey();
+		*saveKey = *key;
 	}
-	else	savekey = key;
+	else	saveKey = key;
 
-	searchkey = (scope)?scope->clone():(key->Persist())?key->clone():0;
-	if (searchkey) {
-		searchkey->Persist(1);
-		setKey(*searchkey);
+	searchKey = (scope)?scope->clone():(key->Persist())?key->clone():0;
+	if (searchKey) {
+		searchKey->Persist(1);
+		setKey(*searchKey);
 	}
 
 	(*percent)(perc, percentUserData);
@@ -457,69 +477,95 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 
 #ifdef USELUCENE
 	if (searchType == -4) {	// lucene
-		// test to see if our scope for this search is bounded by a
-		// VerseKey
-		VerseKey *testKeyType = 0, vk;
-		SWTRY {
-			testKeyType = SWDYNAMIC_CAST(VerseKey, ((scope)?scope:key));
-		}
-		SWCATCH ( ... ) {}
-		// if we don't have a VerseKey * decendant we can't handle
-		// because of scope.
+		//Buffers for the wchar<->utf8 char* conversion
+		const unsigned short int MAX_CONV_SIZE = 2047;
+		wchar_t wcharBuffer[MAX_CONV_SIZE + 1];
+		char utfBuffer[MAX_CONV_SIZE + 1];
+		
+		
+		// Make sure our scope for this search is bounded by
+		// something we can test
 		// In the future, add bool SWKey::isValid(const char *tryString);
-		// For now just drop back to multiword unindexed
-		if (!testKeyType) {
-			searchType = -3;
+		bool freeTestKey = false;
+
+		// only enforce range if we're VerseKey decendant
+		bool enforceRange = SWDYNAMIC_CAST(VerseKey, resultKey);
+
+		SWKey *testKey = 0;
+		if (enforceRange) {
+			SWTRY {
+				testKey = SWDYNAMIC_CAST(VerseKey, ((scope)?scope:key));
+				if (!testKey) {
+					testKey = SWDYNAMIC_CAST(ListKey, ((scope)?scope:key));
+				}
+			}
+			SWCATCH ( ... ) {}
+			if (!testKey) {
+				testKey = new ListKey();
+				*testKey = ((VerseKey *)resultKey)->ParseVerseList((const char *)((scope)?scope:key), *resultKey, true);
+				freeTestKey = true;
+			}
 		}
-		else {
-			lucene::index::IndexReader *ir;
-			lucene::search::IndexSearcher *is;
-			ir = &IndexReader::open(target);
-			is = new IndexSearcher(*ir);
+		lucene::index::IndexReader    *ir = 0;
+		lucene::search::IndexSearcher *is = 0;
+		Query                          *q = 0;
+		Hits                           *h = 0;
+		try {
+			ir = IndexReader::open(target);
+			is = new IndexSearcher(ir);
 			(*percent)(10, percentUserData);
 
 			standard::StandardAnalyzer analyzer;
-			Query &q =  QueryParser::Parse(istr, _T("content"), analyzer);
+			lucene_utf8towcs(wcharBuffer, istr, MAX_CONV_SIZE); //TODO Is istr always utf8?
+			q = QueryParser::parse(wcharBuffer, _T("content"), &analyzer);
 			(*percent)(20, percentUserData);
-			Hits &h = is->search(q);
+			h = is->search(q);
 			(*percent)(80, percentUserData);
 
-
 			// iterate thru each good module position that meets the search
-			for (long i = 0; i < h.Length(); i++) {
-				Document &doc = h.doc(i);
+			for (long i = 0; i < h->length(); i++) {
+				Document &doc = h->doc(i);
 
 				// set a temporary verse key to this module position
-				vk = doc.get(_T("key"));
-
-				// check scope
-				// Try to set our scope key to this verse key
-				if (scope) {
-					*testKeyType = vk;
+				lucene_wcstoutf8(utfBuffer, doc.get(_T("key")), MAX_CONV_SIZE);	
+				*resultKey = utfBuffer; //TODO Does a key always accept utf8?
+				if (enforceRange) {
+					// check scope
+					// Try to set our scope key to this verse key
+					*testKey = *resultKey;
 
 					// check to see if it set ok and if so, add to our return list
-					if (*testKeyType == vk) {
-						listkey << (const char *) vk;
-						listkey.GetElement()->userData = reinterpret_cast<void *>((int)(h.score(i)*100));
+					if (*testKey == *resultKey) {
+						listKey << *resultKey;
+						listKey.GetElement()->userData = (void *)((__u32)(h->score(i)*100));
 					}
 				}
 				else {
-					listkey << (const char*) vk;
-					listkey.GetElement()->userData = reinterpret_cast<void *>((int)(h.score(i)*100));
+					listKey << *resultKey;
+					listKey.GetElement()->userData = (void *)((__u32)(h->score(i)*100));
 				}
 			}
 			(*percent)(98, percentUserData);
+		}
+		catch (...) {
+			q = 0;
+			// invalid clucene query
+		}
+		delete h;
+		delete q;
 
-			delete &h;
-			delete &q;
-
-			delete is;
+		delete is;
+		if (ir) {
 			ir->close();
 		}
+		if (freeTestKey) {
+			delete testKey;
+		}
 	}
 #endif
 
 
+	// multi-word
 	if (searchType == -2) {
 		wordBuf = (char *)calloc(sizeof(char), strlen(istr) + 1);
 		strcpy(wordBuf, istr);
@@ -536,6 +582,7 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 		}
 	}
 
+	// entry attributes
 	if (searchType == -3) {
 		wordBuf = (char *)calloc(sizeof(char), strlen(istr) + 1);
 		char *checkSlash = wordBuf;
@@ -592,22 +639,26 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 		}
 		if (searchType >= 0) {
 			if (!regexec(&preg,  StripText(), 0, 0, 0)) {
-				textkey = KeyText();
-				listkey << textkey;
+				*resultKey = *getKey();
+				listKey << *resultKey;
 			}
 		}
+
+		// phrase
 		else if (searchType == -1) {
 			sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(StripText(), istr) : strstr(StripText(), istr);
 			if (sres) { //it's also in the StripText(), so we have a valid search result item now
-				textkey = KeyText();
-				listkey << textkey;
+				*resultKey = *getKey();
+				listKey << *resultKey;
 			}
 		}
+
+		// multiword
 		else if (searchType == -2) {
 			int loopCount = 0;
 			int foundWords = 0;
 			do {
-				const char* textBuf = (loopCount == 0) ? getRawEntry() : StripText();
+				const char* textBuf = ((loopCount == 0)&&(!specialStrips)) ? getRawEntry() : StripText();
 				foundWords = 0;
 				
 				for (int i = 0; i < wordCount; ++i) {
@@ -622,10 +673,12 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 			} while ( (loopCount < 2) && (foundWords == wordCount));
 			
 			if ((loopCount == 2) && (foundWords == wordCount)) { //we found the right words in both raw and stripped text, which means it's a valid result item
-				textkey = KeyText();
-				listkey << textkey;
+				*resultKey = *getKey();
+				listKey << *resultKey;
 			}
 		}
+
+		// entry attributes
 		else if (searchType == -3) {
 			int i;
 			RenderText();	// force parse
@@ -675,8 +728,8 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 							sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(i3Start->second.c_str(), words[3]) : strstr(i3Start->second.c_str(), words[3]);
 						}
 						if (sres) {
-							textkey = KeyText();
-							listkey << textkey;
+							*resultKey = *getKey();
+							listKey << *resultKey;
 							break;
 						}
 					}
@@ -698,19 +751,23 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 		free(wordBuf);
 	}
 
-	setKey(*savekey);
+	setKey(*saveKey);
 
-	if (!savekey->Persist())
-		delete savekey;
+	if (!saveKey->Persist())
+		delete saveKey;
 
-	if (searchkey)
-		delete searchkey;
+	if (searchKey)
+		delete searchKey;
+	delete resultKey;
 
-	listkey = TOP;
+	listKey = TOP;
 	processEntryAttributes(savePEA);
+
+
 	(*percent)(100, percentUserData);
 
-	return listkey;
+
+	return listKey;
 }
 
 
@@ -733,7 +790,7 @@ const char *SWModule::StripText(const char *buf, int len) {
  *
  * ENT:	buf	- buffer to Render instead of current module position
  *
- * RET: listkey set to verses that contain istr
+ * RET: this module's text at specified key location massaged by RenderText filters
  */
 
  const char *SWModule::RenderText(const char *buf, int len, bool render) {
@@ -778,23 +835,23 @@ const char *SWModule::StripText(const char *buf, int len) {
  */
 
  const char *SWModule::RenderText(SWKey *tmpKey) {
-	SWKey *savekey;
+	SWKey *saveKey;
 	const char *retVal;
 
 	if (!key->Persist()) {
-		savekey = CreateKey();
-		*savekey = *key;
+		saveKey = CreateKey();
+		*saveKey = *key;
 	}
-	else	savekey = key;
+	else	saveKey = key;
 
 	setKey(*tmpKey);
 
 	retVal = RenderText();
 
-	setKey(*savekey);
+	setKey(*saveKey);
 
-	if (!savekey->Persist())
-		delete savekey;
+	if (!saveKey->Persist())
+		delete saveKey;
 
 	return retVal;
 }
@@ -809,23 +866,23 @@ const char *SWModule::StripText(const char *buf, int len) {
  */
 
 const char *SWModule::StripText(SWKey *tmpKey) {
-	SWKey *savekey;
+	SWKey *saveKey;
 	const char *retVal;
 
 	if (!key->Persist()) {
-		savekey = CreateKey();
-		*savekey = *key;
+		saveKey = CreateKey();
+		*saveKey = *key;
 	}
-	else	savekey = key;
+	else	saveKey = key;
 
 	setKey(*tmpKey);
 
 	retVal = StripText();
 
-	setKey(*savekey);
+	setKey(*saveKey);
 
-	if (!savekey->Persist())
-		delete savekey;
+	if (!saveKey->Persist())
+		delete saveKey;
 
 	return retVal;
 }
@@ -867,8 +924,8 @@ void SWModule::deleteSearchFramework() {
 
 signed char SWModule::createSearchFramework(void (*percent)(char, void *), void *percentUserData) {
 #ifdef USELUCENE
-	SWKey *savekey = 0;
-	SWKey *searchkey = 0;
+	SWKey *saveKey = 0;
+	SWKey *searchKey = 0;
 	SWKey textkey;
 	char *word = 0;
 	char *wordBuf = 0;
@@ -876,9 +933,13 @@ signed char SWModule::createSearchFramework(void (*percent)(char, void *), void
 
 	// turn all filters to default values
 	StringList filterSettings;
-	for (FilterList::iterator filter = optionFilters->begin(); filter != optionFilters->end(); filter++) {
+	for (OptionFilterList::iterator filter = optionFilters->begin(); filter != optionFilters->end(); filter++) {
 		filterSettings.push_back((*filter)->getOptionValue());
 		(*filter)->setOptionValue(*((*filter)->getOptionValues().begin()));
+
+		if (!strcmp("Greek Accents", (*filter)->getOptionName())) {
+			(*filter)->setOptionValue("Off");
+		}
 	}
 
 	
@@ -888,22 +949,17 @@ signed char SWModule::createSearchFramework(void (*percent)(char, void *), void
 	// save key information so as not to disrupt original
 	// module position
 	if (!key->Persist()) {
-		savekey = CreateKey();
-		*savekey = *key;
+		saveKey = CreateKey();
+		*saveKey = *key;
 	}
-	else	savekey = key;
+	else	saveKey = key;
 
-	searchkey = (key->Persist())?key->clone():0;
-	if (searchkey) {
-		searchkey->Persist(1);
-		setKey(*searchkey);
+	searchKey = (key->Persist())?key->clone():0;
+	if (searchKey) {
+		searchKey->Persist(1);
+		setKey(*searchKey);
 	}
 
-	// position module at the beginning
-	*this = TOP;
-
-	// iterate thru each entry in module
-
 	IndexWriter *writer = NULL;
 	Directory *d = NULL;
  
@@ -916,25 +972,28 @@ signed char SWModule::createSearchFramework(void (*percent)(char, void *), void
 	FileMgr::createParent(target+"/dummy");
 
 	if (IndexReader::indexExists(target.c_str())) {
-		d = &FSDirectory::getDirectory(target.c_str(), false);
-		if (IndexReader::isLocked(*d)) {
-			IndexReader::unlock(*d);
+		d = FSDirectory::getDirectory(target.c_str(), false);
+		if (IndexReader::isLocked(d)) {
+			IndexReader::unlock(d);
 		}
 																		   
-		writer = new IndexWriter(*d, *an, false);
+		writer = new IndexWriter( d, an, false);
 	} else {
-		d = &FSDirectory::getDirectory(target.c_str(), true);
-		writer = new IndexWriter( *d ,*an, true);
+		d = FSDirectory::getDirectory(target.c_str(), true);
+		writer = new IndexWriter( d ,an, true);
 	}
 
 
  
 	char perc = 1;
 	VerseKey *vkcheck = 0;
-	SWTRY {
-		vkcheck = SWDYNAMIC_CAST(VerseKey, key);
-	}
-	SWCATCH (...) {}
+	vkcheck = SWDYNAMIC_CAST(VerseKey, key);
+
+	TreeKeyIdx *tkcheck = 0;
+	tkcheck = SWDYNAMIC_CAST(TreeKeyIdx, key);
+
+
+	*this = BOTTOM;
 	long highIndex = (vkcheck)?32300/*vkcheck->NewIndex()*/:key->Index();
 	if (!highIndex)
 		highIndex = 1;		// avoid division by zero errors.
@@ -942,12 +1001,28 @@ signed char SWModule::createSearchFramework(void (*percent)(char, void *), void
 	bool savePEA = isProcessEntryAttributes();
 	processEntryAttributes(true);
 
-	while (!Error()) {
+	// prox chapter blocks
+	// position module at the beginning
+	*this = TOP;
+
+	VerseKey chapMax;
+	SWBuf proxBuf;
+	SWBuf proxLem;
+	SWBuf strong;
+
+	const short int MAX_CONV_SIZE = 2047;
+	wchar_t wcharBuffer[MAX_CONV_SIZE + 1];
+	
+	char err = Error();
+	while (!err) {
 		long mindex = 0;
 		if (vkcheck)
 			mindex = vkcheck->NewIndex();
 		else mindex = key->Index();
 
+		proxBuf = "";
+		proxLem = "";
+
 		// computer percent complete so we can report to our progress callback
 		float per = (float)mindex / highIndex;
 		// between 5%-98%
@@ -961,45 +1036,190 @@ signed char SWModule::createSearchFramework(void (*percent)(char, void *), void
 		// get "content" field
 		const char *content = StripText();
 
+		bool good = false;
+
+		// start out entry
+		Document *doc = new Document();
+		// get "key" field
+		SWBuf keyText = (vkcheck) ? vkcheck->getOSISRef() : getKeyText();
 		if (content && *content) {
+			good = true;
 
-			// get "key" field
-			SWBuf keyText = (vkcheck) ? vkcheck->getOSISRef() : getKeyText();
 			
 			// build "strong" field
-			SWBuf strong;
-		
 			AttributeTypeList::iterator words;
 			AttributeList::iterator word;
 			AttributeValue::iterator strongVal;
 
+			strong="";
 			words = getEntryAttributes().find("Word");
 			if (words != getEntryAttributes().end()) {
 				for (word = words->second.begin();word != words->second.end(); word++) {
-					strongVal = word->second.find("Lemma");
-					if (strongVal != word->second.end()) {
-						// cheeze.  skip empty article tags that weren't assigned to any text
-						if (strongVal->second == "G3588") {
-							if (word->second.find("Text") == word->second.end())
-								continue;	// no text? let's skip
+					int partCount = atoi(word->second["PartCount"]);
+					if (!partCount) partCount = 1;
+					for (int i = 0; i < partCount; i++) {
+						SWBuf tmp = "Lemma";
+						if (partCount > 1) tmp.appendFormatted(".%d", i+1);
+						strongVal = word->second.find(tmp);
+						if (strongVal != word->second.end()) {
+							// cheeze.  skip empty article tags that weren't assigned to any text
+							if (strongVal->second == "G3588") {
+								if (word->second.find("Text") == word->second.end())
+									continue;	// no text? let's skip
+							}
+							strong.append(strongVal->second);
+							strong.append(' ');
 						}
-						strong.append(strongVal->second);
-						strong.append(' ');
 					}
 				}
 			}
 
-			// add our entry to the clucene index		
-			Document *doc = new Document();
-			doc->add( Field::UnIndexed(_T("key"), keyText ) );
-			doc->add( Field::UnStored(_T("content"), content) );
-			if (strong.length() > 0)
-				doc->add( Field::UnStored(_T("lemma"), strong) );
-			writer->addDocument(*doc);
-			delete doc;
+			lucene_utf8towcs(wcharBuffer, keyText, MAX_CONV_SIZE); //keyText must be utf8
+			doc->add( *Field::UnIndexed(_T("key"), wcharBuffer ) );
+
+			lucene_utf8towcs(wcharBuffer, content, MAX_CONV_SIZE); //content must be utf8
+			doc->add( *Field::UnStored(_T("content"), wcharBuffer) );
+
+			if (strong.length() > 0) {
+				lucene_utf8towcs(wcharBuffer, strong, MAX_CONV_SIZE);
+				doc->add( *Field::UnStored(_T("lemma"), wcharBuffer) );
+//printf("setting fields (%s).\ncontent: %s\nlemma: %s\n", (const char *)*key, content, strong.c_str());
+			}
+
+//printf("setting fields (%s).\n", (const char *)*key);
+//fflush(stdout);
 		}
+		// don't write yet, cuz we have to see if we're the first of a prox block (5:1 or chapter5/verse1
+
+		// for VerseKeys use chapter
+		if (vkcheck) {
+			chapMax = *vkcheck;
+			// we're the first verse in a chapter
+			if (vkcheck->Verse() == 1) {
+				chapMax = MAXVERSE;
+				VerseKey saveKey = *vkcheck;
+				while ((!err) && (*vkcheck <= chapMax)) {
+//printf("building proxBuf from (%s).\nproxBuf.c_str(): %s\n", (const char *)*key, proxBuf.c_str());
+//printf("building proxBuf from (%s).\n", (const char *)*key);
+
+					content = StripText();
+					if (content && *content) {
+						// build "strong" field
+						strong = "";
+						AttributeTypeList::iterator words;
+						AttributeList::iterator word;
+						AttributeValue::iterator strongVal;
+
+						words = getEntryAttributes().find("Word");
+						if (words != getEntryAttributes().end()) {
+							for (word = words->second.begin();word != words->second.end(); word++) {
+								int partCount = atoi(word->second["PartCount"]);
+								if (!partCount) partCount = 1;
+								for (int i = 0; i < partCount; i++) {
+									SWBuf tmp = "Lemma";
+									if (partCount > 1) tmp.appendFormatted(".%d", i+1);
+									strongVal = word->second.find(tmp);
+									if (strongVal != word->second.end()) {
+										// cheeze.  skip empty article tags that weren't assigned to any text
+										if (strongVal->second == "G3588") {
+											if (word->second.find("Text") == word->second.end())
+												continue;	// no text? let's skip
+										}
+										strong.append(strongVal->second);
+										strong.append(' ');
+									}
+								}
+							}
+						}
+						proxBuf += content;
+						proxBuf.append(' ');
+						proxLem += strong;
+						if (proxLem.length()) 
+							proxLem.append("\n");
+					}
+					(*this)++;
+					err = Error();
+				}
+				err = 0;
+				*vkcheck = saveKey;
+			}
+		}
+		
+		// for TreeKeys use siblings if we have no children
+		else if (tkcheck) {
+			if (!tkcheck->hasChildren()) {
+				if (!tkcheck->previousSibling()) {
+					do {
+//printf("building proxBuf from (%s).\n", (const char *)*key);
+//fflush(stdout);
+
+						content = StripText();
+						if (content && *content) {
+							// build "strong" field
+							strong = "";
+							AttributeTypeList::iterator words;
+							AttributeList::iterator word;
+							AttributeValue::iterator strongVal;
+
+							words = getEntryAttributes().find("Word");
+							if (words != getEntryAttributes().end()) {
+								for (word = words->second.begin();word != words->second.end(); word++) {
+									int partCount = atoi(word->second["PartCount"]);
+									if (!partCount) partCount = 1;
+									for (int i = 0; i < partCount; i++) {
+										SWBuf tmp = "Lemma";
+										if (partCount > 1) tmp.appendFormatted(".%d", i+1);
+										strongVal = word->second.find(tmp);
+										if (strongVal != word->second.end()) {
+											// cheeze.  skip empty article tags that weren't assigned to any text
+											if (strongVal->second == "G3588") {
+												if (word->second.find("Text") == word->second.end())
+													continue;	// no text? let's skip
+											}
+											strong.append(strongVal->second);
+											strong.append(' ');
+										}
+									}
+								}
+							}
+
+							proxBuf += content;
+							proxBuf.append(' ');
+							proxLem += strong;
+							if (proxLem.length()) 
+								proxLem.append("\n");
+						}
+					} while (tkcheck->nextSibling());
+					tkcheck->parent();
+					tkcheck->firstChild();
+				}
+				else tkcheck->nextSibling();	// reposition from our previousSibling test
+			}
+		}
+		
+		if (proxBuf.length() > 0) {
+	
+			lucene_utf8towcs(wcharBuffer, proxBuf, MAX_CONV_SIZE); //keyText must be utf8
+		
+//printf("proxBuf after (%s).\nprox: %s\nproxLem: %s\n", (const char *)*key, proxBuf.c_str(), proxLem.c_str());
+
+			doc->add( *Field::UnStored(_T("prox"), wcharBuffer) );
+			good = true;
+		}
+		if (proxLem.length() > 0) {
+			lucene_utf8towcs(wcharBuffer, proxLem, MAX_CONV_SIZE); //keyText must be utf8
+			doc->add( *Field::UnStored(_T("proxlem"), wcharBuffer) );
+			good = true;
+		}
+		if (good) {
+//printf("writing (%s).\n", (const char *)*key);
+//fflush(stdout);
+			writer->addDocument(doc);
+		}
+		delete doc;
 
 		(*this)++;
+		err = Error();
 	}
 
 	writer->optimize();
@@ -1008,19 +1228,19 @@ signed char SWModule::createSearchFramework(void (*percent)(char, void *), void
 	delete an;
 
 	// reposition module back to where it was before we were called
-	setKey(*savekey);
+	setKey(*saveKey);
 
-	if (!savekey->Persist())
-		delete savekey;
+	if (!saveKey->Persist())
+		delete saveKey;
 
-	if (searchkey)
-		delete searchkey;
+	if (searchKey)
+		delete searchKey;
 
 	processEntryAttributes(savePEA);
 
 	// reset option filters back to original values
 	StringList::iterator origVal = filterSettings.begin();
-	for (FilterList::iterator filter = optionFilters->begin(); filter != optionFilters->end(); filter++) {
+	for (OptionFilterList::iterator filter = optionFilters->begin(); filter != optionFilters->end(); filter++) {
 		(*filter)->setOptionValue(*origVal++);
 	}
 
@@ -1030,6 +1250,29 @@ signed char SWModule::createSearchFramework(void (*percent)(char, void *), void
 #endif
 }
 
+/** OptionFilterBuffer a text buffer
+ * @param filters the FilterList of filters to iterate
+ * @param buf the buffer to filter
+ * @param key key location from where this buffer was extracted
+ */
+void SWModule::filterBuffer(OptionFilterList *filters, SWBuf &buf, SWKey *key) {
+	OptionFilterList::iterator it;
+	for (it = filters->begin(); it != filters->end(); it++) {
+		(*it)->processText(buf, key, this);
+	}
+}
+
+/** FilterBuffer a text buffer
+ * @param filters the FilterList of filters to iterate
+ * @param buf the buffer to filter
+ * @param key key location from where this buffer was extracted
+ */
+void SWModule::filterBuffer(FilterList *filters, SWBuf &buf, SWKey *key) {
+	FilterList::iterator it;
+	for (it = filters->begin(); it != filters->end(); it++) {
+		(*it)->processText(buf, key, this);
+	}
+}
 
 
 SWORD_NAMESPACE_END
