@@ -1,7 +1,7 @@
 /******************************************************************************
 *  swbuf.cpp  - code for SWBuf used as a transport and utility for data buffers
 *
-* $Id: swbuf.cpp,v 1.14 2003/08/13 03:56:14 scribe Exp $
+* $Id: swbuf.cpp 1785 2005-04-30 19:11:12Z scribe $
 *
 * Copyright 2003 CrossWire Bible Society (http://www.crosswire.org)
 *	CrossWire Bible Society
@@ -37,7 +37,8 @@ char SWBuf::junkBuf[JUNKBUFSIZE];
 */
 SWBuf::SWBuf(const char *initVal, unsigned long initSize) {
 	init(initSize);
-	set(initVal);
+	if (initVal)
+		set(initVal);
 }
 
 /******************************************************************************
@@ -56,13 +57,10 @@ SWBuf::SWBuf(const SWBuf &other, unsigned long initSize) {
 *
 */
 SWBuf::SWBuf(char initVal, unsigned long initSize) {
-	init(initSize);
-
-	allocSize = 15;
-	buf = (char *)calloc(allocSize, 1);
+	init(initSize+1);
 	*buf = initVal;
 	end = buf+1;
-	endAlloc = buf + allocSize-1;
+	*end = 0;
 }
 
 /*
@@ -73,65 +71,38 @@ SWBuf::SWBuf(unsigned long initSize) {
 */
 
 
-void SWBuf::init(unsigned long initSize) {
-	fillByte = ' ';
-	allocSize = 0;
-	endAlloc = 0;
-	buf = 0;
-	end = 0;
-	if (initSize)
-		assureSize(initSize);
-}
-
 /******************************************************************************
-* SWBuf Destructor - Cleans up instance of SWBuf
+* SWBuf::setFormatted - sets this buf to a formatted string
+* WARNING: This function can only write at most
+* JUNKBUFSIZE to the string per call.
 */
-SWBuf::~SWBuf() {
-	if (buf)
-		free(buf);
-}
+void SWBuf::setFormatted(const char *format, ...) {
+	va_list argptr;
 
-/******************************************************************************
-* SWBuf::set - sets this buf to a new value
-*/
-void SWBuf::set(const char *newVal) {
-	if (newVal) {
-		unsigned long len = strlen(newVal) + 1;
-		assureSize(len);
-		memcpy(buf, newVal, len);
-		end = buf + (len - 1);
-	}
-	else {
-		assureSize(1);
-		end = buf;
-		*end = 0;
-	}
-}
-
-
-/******************************************************************************
-* SWBuf::set - sets this buf to a new value
-*/
-void SWBuf::set(const SWBuf &newVal) {
-	unsigned long len = newVal.length() + 1;
+	va_start(argptr, format);
+	int len = vsprintf(junkBuf, format, argptr)+1;
+	va_end(argptr);
 	assureSize(len);
-	memcpy(buf, newVal.c_str(), len);
-	end = buf + (len-1);
+	va_start(argptr, format);
+	end = vsprintf(buf, format, argptr) + buf;
+	va_end(argptr);
 }
 
-
 /******************************************************************************
 * SWBuf::append - appends a value to the current value of this SWBuf
+* 
 */
 void SWBuf::append(const char *str, long max) {
-	unsigned long len = (max > -1) ? max : strlen(str);
-	assureMore(++len);
-	memcpy(end, str, len-1);
-	end += (len-1);
+//	if (!str) //A null string was passed
+//		return;
+	if (max < 0)
+		max = strlen(str);
+	assureMore(max+1);
+	for (;((*str)&&(max));max--)
+		*end++ = *str++;
 	*end = 0;
 }
 
-
 /******************************************************************************
 * SWBuf::setSize - Size this buffer to a specific length
 */
@@ -160,4 +131,29 @@ void SWBuf::appendFormatted(const char *format, ...) {
 	va_end(argptr);
 }
 
+void SWBuf::insert(unsigned long pos, const char* str, unsigned long start, signed long max) {
+// 	if (!str) //A null string was passed
+// 		return;
+
+	str += start;
+	int len = (max > -1) ? max : strlen(str);
+
+	if (!len || (pos > length())) //nothing to do, return
+		return;
+	
+	// pos==length(), so we can call append in this case
+	if (pos == length()) { //append is more efficient
+		append(str, max);
+		return;
+	}
+	
+	assureMore( len );
+	
+	memmove(buf + pos + len, buf + pos, (end - buf) - pos); //make a gap of "len" bytes
+	memcpy(buf+pos, str, len);
+	
+	end += len;
+	*end = 0;
+}
+
 SWORD_NAMESPACE_END
