@@ -1,7 +1,7 @@
 /******************************************************************************
  *  utilxml.cpp   - implementaion of utility classes to handle XML processing
  *
- * $Id: utilxml.cpp 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: utilxml.cpp 1947 2006-07-16 02:01:52Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -37,11 +37,17 @@ void XMLTag::parse() const {
 		return;
 	for (i = 0; ((buf[i]) && (!isalpha(buf[i]))); i++);
 	for (; buf[i]; i++) {
-		if (buf[i] == ' ') {
+		if (strchr("\t\r\n ", buf[i])) {
+                        // Convert newlines, carriage returns and tabs to spaces
+			buf[i] = ' ';
+
 			for (; ((buf[i]) && (!isalpha(buf[i]))); i++);
 			if (buf[i]) {		// we have an attribute name
 				start = i;
+				// Deprecated: check for following whitespacee
+				// Should be: for (; (buf[i] && buf[i] != '='; i++);
 				for (; ((buf[i]) && (!strchr(" =", buf[i]))); i++);
+
 				if (i-start) {
 					if (name)
 						delete [] name;
@@ -49,28 +55,56 @@ void XMLTag::parse() const {
 					strncpy(name, buf+start, i-start);
 					name[i-start] = 0;
 				}
-				for (; ((buf[i]) && (strchr(" =\"", buf[i]))); i++);
+
+				// The following does not allow for empty attributes
+				//for (; ((buf[i]) && (strchr(" =\"\'", buf[i]))); i++);
+
+				// skip space preceding the = sign
+				// Deprecated: this is not part of the xml spec
+				for (; buf[i] == ' '; i++) ;
+
+				// skip the = sign
+				if (buf[i])
+					i++;
+
+				// skip space following the = sign
+				// Deprecated: this is not part of the xml spec
+				for (; buf[i] == ' '; i++) ;
+
+				// remember and skip the quote sign
+				char quoteChar = buf[i];
+				if (quoteChar)
+					i++;
+
 				if (buf[i]) {	// we have attribute value
 					start = i;
-					for (; ((buf[i]) && (buf[i] != '\"')); i++);
-					if (i-start) {
+					// Skip until matching quote character
+					for (; ((buf[i]) && (buf[i] != quoteChar)); i++);
+
+					// Allow for empty quotes
+					//if (i-start) {
 						if (value)
 							delete [] value;
 						value = new char [ (i-start) + 1 ];
-						strncpy(value, buf+start, i-start);
+						if (i-start) {
+							strncpy(value, buf+start, i-start);
+						}
 						value[i-start] = 0;
 						attributes[name] = value;
-					}
+					//}
 				}
 			}
 		}
+
+		// if there are no more characters left then quit
 		if (!buf[i])
 			break;
+
 	}
 	for (;i;i--) {
 		if (buf[i] == '/')
 			empty = true;
-		if (!strchr(" \n>\t", buf[i]))
+		if (!strchr(" \t\r\n>\t", buf[i]))
 			break;
 	}
 		
@@ -111,7 +145,7 @@ void XMLTag::setText(const char *tagString) {
 			endTag = true;
 	}
 	start = i;
-	for (; ((tagString[i]) && (!strchr(" />", tagString[i]))); i++);
+	for (; ((tagString[i]) && (!strchr("\t\r\n />", tagString[i]))); i++);
 	if (i-start) {
 		if (name)
 			delete [] name;
@@ -212,9 +246,9 @@ const char *XMLTag::toString() const {
 		//tag.appendFormatted(" %s=\"%s\"", it->first.c_str(), it->second.c_str());
 		tag.append(' ');
 		tag.append(it->first.c_str());
-		tag.append("=\"");
+		tag.append((strchr(it->second.c_str(), '\"')) ? "=\'" : "=\"");
 		tag.append(it->second.c_str());
-		tag.append('"');
+		tag.append((strchr(it->second.c_str(), '\"'))? '\'' : '\"');
 	}
 
 	if (isEmpty())
