@@ -41,3 +41,24 @@
 ../parsekey "1. Johannes 1:1-3:10" "de"
 ../parsekey "1. Joh 1:1-3:10" "de"
 ../parsekey "1Jn 1:1-3:10"
+../parsekey "1. Johannes 1:1 - 3:10" "de"
+../parsekey "1. Joh 1:1 - 3:10" "de"
+../parsekey "1Jn 1:1 - 3:10"
+../parsekey "1. Johannes 1:1 -3:10" "de"
+../parsekey "1. Joh 1:1 -3:10" "de"
+../parsekey "1Jn 1:1 -3:10"
+../parsekey "1. Johannes 1:1- 3:10" "de"
+../parsekey "1. Joh 1:1- 3:10" "de"
+../parsekey "1Jn 1:1- 3:10"
+
+### List parsing tests
+../parsekey "1Jn 1:1 3:10"
+../parsekey "1Jn 1:1  3:10"
+../parsekey "1Jn 1:1,3:10"
+../parsekey "1Jn 1:1, 3:10"
+../parsekey "1Jn 1:1 ,3:10"
+../parsekey "1Jn 1:1 , 3:10"
+../parsekey "1Jn 1:1;3:10"
+../parsekey "1Jn 1:1; 3:10"
+../parsekey "1Jn 1:1 ;3:10"
+../parsekey "1Jn 1:1 ; 3:10"
