@@ -25,9 +25,6 @@ using sword::zLD;
 using sword::RawLD;
 #endif
 
-#ifndef O_BINARY
-#define O_BINARY 0
-#endif
 
 int main(int argc, char **argv) {
   
