@@ -19,6 +19,9 @@
 #include <utilxml.h>
 #include <versekey.h>
 #include <swmodule.h>
+#ifdef WIN32
+#include <ctype.h>
+#endif
 
 SWORD_NAMESPACE_START
 
@@ -154,7 +157,8 @@ bool OSISCGI::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 				if (!tag.isEmpty()) {
 					SWBuf type = tag.getAttribute("type");
 
-					if (type != "strongsMarkup") {	// leave strong's markup notes out, in the future we'll probably have different option filters to turn different note types on or off
+					if (type != "x-strongsMarkup" &&	// leave strong's markup notes out, in the future we'll probably have different option filters to turn different note types on or off
+					    type != "strongsMarkup") {	// deprecated
 						SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 						VerseKey *vkey;
 						// see if we have a VerseKey * or descendant
@@ -222,8 +226,8 @@ bool OSISCGI::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 			}
 		}
 
-		// <milestone type="line"/>
-		else if ((!strcmp(tag.getName(), "milestone")) && (tag.getAttribute("type")) && (!strcmp(tag.getAttribute("type"), "line"))) {
+		// <milestone type="line"/> or <lb.../>
+		else if ((!strcmp(tag.getName(), "lb")) || ((!strcmp(tag.getName(), "milestone")) && (tag.getAttribute("type")) && (!strcmp(tag.getAttribute("type"), "line")))) {
 			buf += "<br />";
 			userData->supressAdjacentWhitespace = true;
 		}
