@@ -18,11 +18,13 @@
 #define THMLCGI_H
 
 #include <swbasicfilter.h>
+#include <map>
 
 #include <defs.h>
 
 SWORD_NAMESPACE_START
 
+typedef std::map<SWBuf, SWBuf> DualStringMap;
 /** this filter converts ThML text to Diatheke/CGI format
  */
 class SWDLLEXPORT ThMLCGI : public SWBasicFilter {
