@@ -1,21 +1,14 @@
-#include <ctype.h>
-#include <stdio.h>
-#include <fcntl.h>
-#include <errno.h>
-#include <stdlib.h>
-
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
-
-#include <iostream>
 #include <string>
+#include <vector>
+#include <fstream>
+#include <iostream>
 #include <rawld.h>
 #include <rawld4.h>
 #include <zld.h>
 #include <zipcomprs.h>
+#include <stdio.h>
+
+using std::string;
 
 #ifndef NO_SWORD_NAMESPACE
 using sword::zLD;
@@ -25,34 +18,19 @@ using sword::RawLD;
 using sword::SWKey;
 #endif
 
-int readline(FILE* infile, char* linebuffer) {
-  signed char c;
-  char* lbPtr = linebuffer;
-  while ((c = fgetc(infile)) != EOF) {
-    *lbPtr++ = c;
-    if (c == 10) {
-      *lbPtr = 0;
-      return (strlen(linebuffer));
-    }
-  }
-  return 0;
-}
 
 int main(int argc, char **argv) {
 
   const char * helptext ="imp2ld 1.0 Lexicon/Dictionary/Daily Devotional/Glossary module creation tool for the SWORD Project\n  usage:\n   %s <filename> [modname] [ 4 (default) | 2 | z - module driver]\n";
 
   signed long i = 0;
-  char* keybuffer = new char[2048];
-  char* entbuffer = new char[1048576];
-  char* linebuffer = new char[1048576];
+  string keybuffer;
+  string entbuffer;
+  string linebuffer;
   char modname[16];
   char links = 0;
-  char* linkbuffer[32];
-  while (i < 32) {
-        linkbuffer[i] = new char[256];
-        i++;
-  }
+  std::vector<string> linkbuffer;
+
   if (argc > 2) {
     strcpy (modname, argv[2]);
   }
@@ -67,8 +45,7 @@ int main(int argc, char **argv) {
     exit(-1);
   }
 
-  FILE *infile;
-  infile = fopen(argv[1], "r");
+  std::ifstream infile(argv[1]);
 
   char mode = 1;
   if (argc > 3) {
@@ -107,74 +84,75 @@ int main(int argc, char **argv) {
 
   key->Persist(1);
 
-  while (readline(infile, linebuffer)) {
-    if (!strncmp(linebuffer, "$$$", 3)) {
-      if (strlen(keybuffer) && strlen(entbuffer)) {
+  while (!infile.eof()) {
+    std::getline(infile, linebuffer);
+    if (linebuffer.size() > 3 && linebuffer.substr(0,3) == "$$$") {
+      if (keybuffer.size() && entbuffer.size()) {
 	std::cout << keybuffer << std::endl;
-	*key = keybuffer;
+	*key = keybuffer.c_str();
 
 	if (mode == 3) {
 	  modZ->setKey(*key);
-	  modZ->setEntry(entbuffer, strlen(entbuffer));
+	  modZ->setEntry(entbuffer.c_str(), entbuffer.size());
           for (i = 0; i < links; i++) {
-                SWKey tmpkey = linkbuffer[i];
+                SWKey tmpkey = linkbuffer[i].c_str();
                 modZ->linkEntry(&tmpkey);
                 std::cout << "Linking: " << linkbuffer[i] << std::endl;
           }
 	}
 	else if (mode == 2) {
 	  mod2->setKey(*key);
-	  mod2->setEntry(entbuffer, strlen(entbuffer));
+	  mod2->setEntry(entbuffer.c_str(), entbuffer.size());
           for (i = 0; i < links; i++) {
-                SWKey tmpkey = linkbuffer[i];
+                SWKey tmpkey = linkbuffer[i].c_str();
                 mod2->linkEntry(&tmpkey);
                 std::cout << "Linking: " << linkbuffer[i] << std::endl;
           }
 	}
 	else if (mode == 1) {
 	  mod4->setKey(*key);
-	  mod4->setEntry(entbuffer, strlen(entbuffer));
+	  mod4->setEntry(entbuffer.c_str(), entbuffer.size());
           for (i = 0; i < links; i++) {
-                SWKey tmpkey = linkbuffer[i];
+                SWKey tmpkey = linkbuffer[i].c_str();
                 mod4->linkEntry(&tmpkey);
                 std::cout << "Linking: " << linkbuffer[i] << std::endl;
           }
 	}
       }
-      linebuffer[strlen(linebuffer) - 1] = 0;
-      strcpy (keybuffer, linebuffer + 3);
-      *entbuffer = 0;
+      if (linebuffer.size() > 3)
+      	keybuffer = linebuffer.substr(3,linebuffer.size()) ;
+      entbuffer.resize(0);
+      linkbuffer.clear();
       links = 0;
     }
-    else if (!strncmp(linebuffer, "%%%", 3)) {
-      strcpy (linkbuffer[links], linebuffer + 3);
-      linkbuffer[links][strlen(linkbuffer[links]) - 1] = 0;
+    else if (linebuffer.size() > 3 && linebuffer.substr(0,3) == "%%%") {
+      linkbuffer.push_back(linebuffer.substr(3,linebuffer.size()));
       links++;
     }
     else {
-      strcat (entbuffer, linebuffer);
+      entbuffer += linebuffer;
     }
   }
 
   //handle final entry
-  if (strlen(keybuffer) && strlen(entbuffer)) {
+  if (keybuffer.size() && entbuffer.size()) {
     std::cout << keybuffer << std::endl;
-    *key = keybuffer;
+    *key = keybuffer.c_str();
 
     if (mode == 3) {
 	  modZ->setKey(*key);
-          modZ->setEntry(entbuffer, strlen(entbuffer));
+          modZ->setEntry(entbuffer.c_str(), entbuffer.size());
           for (i = 0; i < links; i++) {
-                SWKey tmpkey = linkbuffer[i];
+                SWKey tmpkey = linkbuffer[i].c_str();
                 modZ->linkEntry(&tmpkey);
                 std::cout << "Linking: " << linkbuffer[i] << std::endl;
           }
     }
     else if (mode == 2) {
 	  mod2->setKey(*key);
-          mod2->setEntry(entbuffer, strlen(entbuffer));
+          mod2->setEntry(entbuffer.c_str(), entbuffer.size());
           for (i = 0; i < links; i++) {
-                SWKey tmpkey = linkbuffer[i];
+                SWKey tmpkey = linkbuffer[i].c_str();
                 mod2->linkEntry(&tmpkey);
                 std::cout << "Linking: " << linkbuffer[i] << std::endl;
           }
@@ -182,21 +160,16 @@ int main(int argc, char **argv) {
     }
     else if (mode == 1) {
           mod4->setKey(*key);
-          mod4->setEntry(entbuffer, strlen(entbuffer));
+          mod4->setEntry(entbuffer.c_str(), entbuffer.size());
           for (i = 0; i < links; i++) {
-                SWKey tmpkey = linkbuffer[i];
+                SWKey tmpkey = linkbuffer[i].c_str();
                 mod4->linkEntry(&tmpkey);
                 std::cout << "Linking: " << linkbuffer[i] << std::endl;
           }
 
     }
   }
-
-  //DEBUG  printTree(root, treeKey);
-
-  delete keybuffer;
-  delete entbuffer;
-  delete linebuffer;
+  infile.close();
 
   return 0;
 }
