@@ -3,16 +3,13 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <stdlib.h>
-
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
+#include <string>
+#include <fstream>
+using namespace std;
 
 #include <iostream>
-#include <string>
 #include <rawtext.h>
+#include <versekey.h>
 
 
 #ifndef NO_SWORD_NAMESPACE
@@ -22,46 +19,34 @@ using sword::SWText;
 using sword::ListKey;
 #endif
 
-int readline(FILE* infile, char* linebuffer) {
-  signed char c;
-  char* lbPtr = linebuffer;
-  while ((c = fgetc(infile)) != EOF) {
-    *lbPtr++ = c;
-    if (c == 10) {
-      *lbPtr = 0;
-      return (strlen(linebuffer));
-    }
-  }
-  return 0;
-}
-
 int main(int argc, char **argv) {
   
-  const char * helptext ="imp2vs 1.0 Bible/Commentary module creation tool for the SWORD Project\n  usage:\n   %s <filename> [output dir] \n";
+  const string helptext ="imp2vs 1.0 Bible/Commentary module creation tool for the SWORD Project\n  usage:\n   %s <filename> [output dir] \n";
   
   signed long i = 0;
-  char* keybuffer = new char[2048];
-  char* entbuffer = new char[1048576];
-  char* linebuffer = new char[1048576];
-  char modname[16];
+  string keybuffer = "";
+  string entbuffer = "";
+  string linebuffer = "";
+  string modname = "";
   
   if (argc > 2) {
-    strcpy (modname, argv[2]);
+    modname = argv[2];
   }
   else if (argc > 1) {
-    strcpy (modname, "./");
+    modname = "./";
   }
   else {
-    fprintf(stderr, helptext, argv[0]);
+    fprintf(stderr, helptext.c_str(), argv[0]);
     exit(-1);
   }
   
-  FILE *infile;
-  infile = fopen(argv[1], "r");
+  try {
+  
+  ifstream infile(argv[1]);
 
   SWText* mod;
-  RawText::createModule(modname);
-  RawText modRaw(modname);
+  RawText::createModule(modname.c_str());
+  RawText modRaw(modname.c_str());
   mod = &modRaw;
 
   VerseKey* vkey = new VerseKey;
@@ -71,13 +56,14 @@ int main(int argc, char **argv) {
   mod->setKey(*vkey);
   char final; // 2 == pre-final line; 1 == final line; 0 == EOF
 
-  final = ((bool)(readline(infile, linebuffer)) + 1);
+  getline(infile,linebuffer);
+  final = (!infile.eof()) + 1;
 
   while (final) {
-    if (!strncmp(linebuffer, "$$$", 3) || final == 1) {
-      if (strlen(keybuffer) && strlen(entbuffer)) {
+    if (final == 1 || (linebuffer.size() > 3 && linebuffer.substr(0,3) == "$$$")) {
+      if (keybuffer.size() && entbuffer.size()) {
 	std::cout << "from file: " << keybuffer << std::endl;
-	*vkey = keybuffer;
+	*vkey = keybuffer.c_str();
 	if (!vkey->Chapter()) {
 	  // bad hack:  0:0 is Book intro; (chapter):0 is Chapter intro; 0:2 is Module intro; 0:1 is Testament intro
 	  int backstep = vkey->Verse();
@@ -95,11 +81,11 @@ int main(int argc, char **argv) {
 		  vkey->Verse(0);
        }
 
-	  std::cout << "adding entry: " << *vkey << std::endl;
-	  mod->setEntry(entbuffer, strlen(entbuffer));
+	  std::cout << "adding entry: " << *vkey << " length " << entbuffer.size() << "/" << (unsigned short)entbuffer.size() << std::endl;
+	  mod->setEntry(entbuffer.c_str(), entbuffer.size());
 	}
 	else {
-	  ListKey listkey = vkey->ParseVerseList(keybuffer, "Gen1:1", true);
+	  ListKey listkey = vkey->ParseVerseList(keybuffer.c_str(), "Gen1:1", true);
 	  int i;
 	  bool havefirst = false;
 	  VerseKey firstverse;
@@ -116,8 +102,8 @@ int main(int argc, char **argv) {
 		havefirst = true;
 		firstverse = *vkey;
 
-	     std::cout << "adding entry: " << *vkey << std::endl;
-		mod->setEntry(entbuffer, strlen(entbuffer));
+		std::cout << "adding entry: " << *vkey << " length " << entbuffer.size() << "/" << (unsigned short)entbuffer.size() << std::endl;
+		mod->setEntry(entbuffer.c_str(), entbuffer.size());
 		(*vkey)++;
 	      }
 	      while (! (finalkey < (*vkey))) {
@@ -137,29 +123,38 @@ int main(int argc, char **argv) {
 		havefirst = true;
 		firstverse = *vkey;
 
-	     std::cout << "adding entry: " << *vkey << std::endl;
-		mod->setEntry(entbuffer, strlen(entbuffer));
+		std::cout << "adding entry: " << *vkey << " length " << entbuffer.size() << "/" << (unsigned short)entbuffer.size() << std::endl;
+		mod->setEntry(entbuffer.c_str(), entbuffer.size());
 	      }
 	    }
 	  }
 	}
       }
-      linebuffer[strlen(linebuffer) - 1] = 0;
-      strcpy (keybuffer, linebuffer + 3);
-      *entbuffer = 0;
+      if (linebuffer.size() > 3)
+	      keybuffer = linebuffer.substr(3,linebuffer.size()) ;
+      entbuffer.resize(0);
     }
     else {
-      strcat (entbuffer, linebuffer);
+      entbuffer.append(linebuffer);
     }
     final--;
     if (final) {
-        final = ((bool)(readline(infile, linebuffer)) + 1);
+      getline(infile,linebuffer);
+      final = (!infile.eof()) + 1;
     }
   }
-
-  delete entbuffer;
-  delete linebuffer;
-  delete keybuffer;
+  }
+  catch (const std::exception& e) {
+         std::cerr << "Exception: imp2vs failed: " << e.what() << std::endl;
+	 std::cerr << "Line: " << linebuffer.size() << " " << linebuffer << std::endl;
+	 std::cerr << "Key: "  << keybuffer.size() << " " << keybuffer << std::endl;
+	 std::cerr << "Ent: "  << entbuffer.size() << " " << entbuffer << std::endl;
+         return -2;
+  }
+  catch (...) {
+         std::cerr << "Exception: imp2vs failed" << std::endl;
+         return -3;
+  }
 
   return 0;
 }
