@@ -3,6 +3,8 @@
 #include <filemgr.h>
 #include <iostream>
 #include <string>
+#include <swmodule.h>
+#include <stdio.h>
 
 using namespace sword;
 using std::cout;
