@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <rawtext.h>
 #include <swmgr.h>
+#include <versekey.h>
 #include <markupfiltmgr.h>
 #include <swbuf.h>
 
@@ -32,10 +33,10 @@ void percentUpdate(char percent, void *userData) {
 
 int main(int argc, char **argv)
 {
-	SWMgr manager(new sword::MarkupFilterMgr(sword::FMT_HTMLHREF, sword::ENC_UTF16));
-	SWModule &kjv = *(manager.Modules["KJV"]);
-	for (kjv.setKey("Gen 1:1"); ((VerseKey *)kjv.getKey())->Chapter() == 1; kjv++) {
-		SWBuf x = kjv.RenderText();
+
+	if (argc != 2) {
+		fprintf(stderr, "usage: %s <modname>\n", argv[0]);
+		exit(-1);
 	}
 	
 	SWModule *target;
@@ -43,11 +44,7 @@ int main(int argc, char **argv)
 	VerseKey vk;
 	ModMap::iterator it;
 
-	if (argc != 2) {
-		fprintf(stderr, "usage: %s <modname>\n", argv[0]);
-		exit(-1);
-	}
-
+	SWMgr manager;
 	it = manager.Modules.find(argv[1]);
 	if (it == manager.Modules.end()) {
 		fprintf(stderr, "Could not find module [%s].  Available modules:\n", argv[1]);
@@ -67,6 +64,7 @@ int main(int argc, char **argv)
 	target->deleteSearchFramework();
 	printf("Building framework, please wait...\n");
 	char lineLen = 70;
+	printf("[0=================================50===============================100]\n ");
 	char error = target->createSearchFramework(&percentUpdate, &lineLen);
 	if (error) {
 		fprintf(stderr, "%s: couldn't create search framework (permissions?)\n", *argv);
