@@ -20,10 +20,20 @@
 #include <versekey.h>
 #include <stdio.h>
 
+#ifndef NO_SWORD_NAMESPACE
+using sword::SWModule;
+using sword::SWMgr;
+using sword::ModMap;
+using sword::SWKey;
+using sword::VerseKey;
+using sword::SW_POSITION;
+#endif
+
+
 void errorOutHelp(char *appName) {
-	cerr << appName << " - a tool to output a Sword module in SWORD's 'imp' import format\n";
-	cerr << "usage: "<< appName << " <modname> \n";
-	cerr << "\n\n";
+	std::cerr << appName << " - a tool to output a Sword module in SWORD's 'imp' import format\n";
+	std::cerr << "usage: "<< appName << " <modname> \n";
+	std::cerr << "\n\n";
 	exit(-1);
 }
 
@@ -57,8 +67,8 @@ int main(int argc, char **argv)
 		vkey->Headings(1);
 
 	for ((*inModule) = TOP; !inModule->Error(); (*inModule)++) {
-		cout << "$$$" << inModule->KeyText() << endl;
-		cout << inModule->getRawEntry() << endl;
+		std::cout << "$$$" << inModule->KeyText() << std::endl;
+		std::cout << inModule->getRawEntry() << std::endl;
 	}
 	return 0;
 }
