@@ -1,5 +1,8 @@
 #include <swmgr.h>
+#include <swmodule.h>
+#include <swkey.h>
 #include <versekey.h>
+#include <stdio.h>
 #include <iostream>
 #ifndef NO_SWORD_NAMESPACE
 using sword::SWMgr;
